@@ -1,6 +1,6 @@
 <?php
     /*
-     * $Id: gpl.php,v 1.3 2001/09/24 02:23:25 mdean Exp $
+     * $Id: gpl.php,v 1.3.4.2 2003/12/12 04:49:08 mdean Exp $
      *
      * Double Choco Latte - Source Configuration Management System
      * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
@@ -22,6 +22,9 @@
      * Select License Info from the Help menu to view the terms and conditions of this license.
      */
 
+include_once('login.php');
+$g_oSec = CreateObject('dcl.boSecurity');
+
 $bInPHPGroupWare = false;
 if (file_exists('../header.inc.php'))
 {
@@ -33,23 +36,21 @@ if (file_exists('../header.inc.php'))
 	include('../header.inc.php');
 	$bInPHPGroupWare = (isset($GLOBALS['phpgw']) && is_object($GLOBALS['phpgw']));
 }
+
 if ($bInPHPGroupWare)
 {
 	$GLOBALS['phpgw']->common->phpgw_header();
 	echo parse_navbar();
 }
-else
-{
-	include('login.php');
-}
+
 commonHeader();
 ?>
-<TABLE BORDER=0 BGColor="<?php echo $GLOBALS['dcl_info']['DCL_COLOR_DARK']; ?>" CELLSPACING="0" CELLPADDING="2">
-<TR><TH><FONT COLOR="<?php echo $GLOBALS['dcl_info']['DCL_COLOR_LIGHT']; ?>">Double Choco Latte, Copyright (C) 1999 Michael L. Dean &amp; Tim R. Norman<BR>
-Double Choco Latte comes with ABSOLUTELY NO WARRANTY; for details see below.</FONT>
-</TH></TR><TR><TD>
-<TABLE BORDER=0 BGCOLOR="<?php echo $GLOBALS['dcl_info']['DCL_COLOR_LIGHT']; ?>">
+<TABLE BORDER=0 CELLSPACING="0" CELLPADDING="2">
+<TR><TH class="formTitle">Double Choco Latte, Copyright (C) 1999-2003 Free Software Foundation
+</TH></TR><TR><TD class="formContainer">
+<TABLE BORDER=0>
 <TR><TD>
+Double Choco Latte comes with ABSOLUTELY NO WARRANTY; for details see below.<BR>
 <H2>GNU GENERAL PUBLIC LICENSE</H2>
 <P>
 Version 2, June 1991
