@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: class.boTickets.inc.php,v 1.10.2.2.2.4 2003/01/29 05:43:10 mdean Exp $
+ * $Id: class.boTickets.inc.php,v 1.10.2.2.2.12 2003/12/10 05:54:06 mdean Exp $
  *
  * Double Choco Latte - Source Configuration Management System
  * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
@@ -84,6 +84,23 @@ class boTickets
 		$obj->seconds = 0;
 		$obj->Add();
 
+		// upload a file attachment?
+		if (IsSet($GLOBALS['userfile']) && $GLOBALS['userfile'] != 'none')
+		{
+			if (!((IsSet($HTTP_POST_VARS['userfile']) && $HTTP_POST_VARS['userfile'] == $GLOBALS['userfile']) ||
+				(IsSet($HTTP_GET_VARS['userfile']) && $HTTP_GET_VARS['userfile'] == $GLOBALS['userfile']) ||
+				(IsSet($HTTP_COOKIE_VARS['userfile']) && $HTTP_COOKIE_VARS['userfile'] == $GLOBALS['userfile'])))
+			{
+				$o = CreateObject('dcl.boFile');
+				$o->iType = ATTACHMENT_TICKET;
+				$o->iKey1 = $obj->ticketid;
+				$o->sFileName = is_array($GLOBALS['userfile']) ? $GLOBALS['userfile']['name'] : $GLOBALS['userfile_name'];
+				$o->sTempFileName = is_array($GLOBALS['userfile']) ? $GLOBALS['userfile']['tmp_name'] : $GLOBALS['userfile'];
+				$o->sRoot = $dcl_info['DCL_FILE_PATH'] . '/attachments';
+				$o->Upload();
+			}
+		}
+
 		if ($GLOBALS['resolution'] != '')
 		{
 			$objR = CreateObject('dcl.dbTicketresolutions');
@@ -186,8 +203,8 @@ class boTickets
 
 		$obj->Edit();
 
-		if ($oldResponsible != $obj->responsible && $obj->responsible != $GLOBALS['DCLID'])
-			$this->SendNewMailMsg($obj);
+		$objWtch = CreateObject('dcl.boWatches');
+		$objWtch->sendTicketNotification($obj, '4');
 
 		$objH = CreateObject('dcl.htmlTicketDetail');
 		$objH->Show($obj);
@@ -223,15 +240,15 @@ class boTickets
 
 		// Remove all attachments
 		$attachPath = $dcl_info['DCL_FILE_PATH'] . '/attachments/tck/' . substr($GLOBALS['ticketid'], -1) . '/' . $GLOBALS['ticketid'] . '/';
-		if ($hDir = @opendir($attachPath))
+		if (is_dir($attachPath) && $hDir = opendir($attachPath))
 		{
-			while ($fileName = @readdir($hDir))
+			while ($fileName = readdir($hDir))
 			{
 				if (is_file($attachPath . $fileName) && is_readable($attachPath . $fileName))
 					unlink($attachPath . $fileName);
 			}
 
-			@closedir($hDir);
+			closedir($hDir);
 		}
 
 		print('<center>');
@@ -304,12 +321,10 @@ class boTickets
 		$endDate->SetFromDisplay($GLOBALS['dateFrom'] . ' 23:59:59');
 		$beginDate->SetFromDisplay($GLOBALS['dateFrom'] . ' 00:00:00');
 		$beginDate->time -= (($GLOBALS["days"] - 1) * 86400);
-		$query = 'SELECT createdon,closedon FROM tickets WHERE ';
-		$query .= '(createdon between ' . $obj->DisplayToSQL($beginDate->ToDisplay());
-		$query .= ' AND ' . $obj->DisplayToSQL($endDate->ToDisplay());
-		$query .= ') OR (closedon between ' . $obj->DisplayToSQL($beginDate->ToDisplay());
-		$query .= ' AND ' . $obj->DisplayToSQL($endDate->ToDisplay()) . ')';
-		$obj->Query($query);
+
+		$product_id = IsSet($GLOBALS['product']) ? intval($GLOBALS['product']) : 0;
+		if ($obj->LoadDatesByRange($beginDate->ToDisplay(), $endDate->ToDisplay(), $product_id) == -1)
+			return;
 
 		$objG->data[0] = array(); // Open
 		$objG->data[1] = array(); // Closed
@@ -349,6 +364,14 @@ class boTickets
 		}
 
 		$objG->title = STR_BO_GRAPHTITLE;
+		if ($product_id > 0)
+		{
+			$oDB = CreateObject('dcl.dbProducts');
+			$oDB->Connect();
+			if ($oDB->Load($product_id) != -1)
+				$objG->title .= ' ' . $oDB->name;
+		}
+
 		$objG->caption_y = STR_BO_GRAPHCAPTIONY;
 		$objG->caption_x = STR_BO_GRAPHCAPTIONX;
 		$objG->num_lines_y = 15;
@@ -394,8 +417,9 @@ class boTickets
 			$obj->priority = $GLOBALS['priority'];
 			$obj->type = $GLOBALS['type'];
 			$obj->Edit();
-			if ($obj->responsible != $GLOBALS['DCLID'])
-				$this->SendNewMailMsg($obj);
+			
+			$objWtch = CreateObject('dcl.boWatches');
+			$objWtch->sendTicketNotification($obj, '4');
 		}
 
 		$objHT = CreateObject('dcl.htmlTicketDetail');
@@ -442,8 +466,8 @@ class boTickets
 			$o = CreateObject('dcl.boFile');
 			$o->iType = ATTACHMENT_TICKET;
 			$o->iKey1 = $GLOBALS['ticketid'];
-			$o->sFileName = $GLOBALS['userfile_name'];
-			$o->sTempFileName = $GLOBALS['userfile'];
+			$o->sFileName = is_array($GLOBALS['userfile']) ? $GLOBALS['userfile']['name'] : $GLOBALS['userfile_name'];
+			$o->sTempFileName = is_array($GLOBALS['userfile']) ? $GLOBALS['userfile']['tmp_name'] : $GLOBALS['userfile'];
 			$o->sRoot = $dcl_info['DCL_FILE_PATH'] . '/attachments';
 			$o->Upload();
 		}
@@ -500,7 +524,7 @@ class boTickets
 		global $responsible, $createdby, $closedby, $personnel, $product;
 		global $type, $priority, $status, $account;
 		global $createdon, $closedon, $statuson, $lastactionon;
-		global $dateFrom, $dateTo;
+		global $dateFrom, $dateTo, $module_id, $dcl_status_type, $department;
 		global $searchText, $columns, $groups, $order, $columnhdrs;
 
 		if (strlen($columnhdrs) > 0)
@@ -526,23 +550,119 @@ class boTickets
 		$objView = CreateObject('dcl.boView');
 		$objView->table = 'tickets';
 
-		if (count($personnel) > 0)
+		if (count($personnel) > 0 || count($department) > 0)
 		{
 			$fieldList = array('responsible', 'createdby', 'closedby');
+			$bStrippedDepartments = false;
+			$pers_sel = array();
 			while (list($key, $field) = each($fieldList))
 			{
 				if ($$field == '1')
-					$objView->AddDef('filter', $field, $personnel);
+				{
+					if (count($personnel) > 0)
+					{
+						if (!$bStrippedDepartments)
+						{
+							$bStrippedDepartments = true;
+
+							// Have actual personnel?  If so, only set personnel for their associated departments instead of the department
+							// then unset the department from the array
+							reset($personnel);
+							while (list(, $encoded_pers) = each($personnel))
+							{
+								list($dpt_id, $pers_id) = explode(',', $encoded_pers);
+								$pers_sel[count($pers_sel)] = $pers_id;
+								if (count($department) > 0 && in_array($dpt_id, $department))
+								{
+									reset($department);
+									while(list($key, $department_id) = each($department))
+									{
+										if ($department_id == $dpt_id)
+										{
+											unset($department[$key]);
+											break;
+										}
+									}
+								}
+							}
+						}
+
+						$objView->AddDef('filter', $field, $pers_sel);
+					}
+
+					if (count($department) > 0)
+						$objView->AddDef('filter', $field . '.department', $department);
+				}
 			}
 		}
 
-		$fieldList = array('product', 'priority', 'type', 'account', 'status');
+		$fieldList = array('priority', 'type', 'account');
 		while (list($key, $field) = each($fieldList))
 		{
 			if (count($$field) > 0)
 				$objView->AddDef('filter', $field, $$field);
 		}
 
+		if (count($module_id) > 0)
+		{
+			// Have modules?  If so, only set module IDs for their associated products instead of the product ID
+			// then unset the product id from the array
+			reset($module_id);
+			$module = array();
+			while (list(, $encoded_mod) = each($module_id))
+			{
+				list($mod_prod_id, $mod_id) = explode(',', $encoded_mod);
+				$module[count($module)] = $mod_id;
+				if (count($product) > 0 && in_array($mod_prod_id, $product))
+				{
+					reset($product);
+					while(list($key, $product_id) = each($product))
+					{
+						if ($product_id == $mod_prod_id)
+						{
+							unset($product[$key]);
+							break;
+						}
+					}
+				}
+			}
+
+			$objView->AddDef('filter', 'module_id', $module);
+		}
+
+		if (count($product) > 0)
+			$objView->AddDef('filter', 'product', $product);
+
+		if (count($status) > 0)
+		{
+			// Have statuses?  If so, only set status IDs for their associated types instead of the status type ID
+			// then unset the status type id from the array
+			reset($status);
+			$statuses = array();
+			while (list(, $encoded_status) = each($status))
+			{
+				list($type_id, $status_id) = explode(',', $encoded_status);
+				$statuses[count($statuses)] = $status_id;
+				if (count($dcl_status_type) > 0 && in_array($type_id, $dcl_status_type))
+				{
+					reset($dcl_status_type);
+					while(list($key, $status_type_id) = each($dcl_status_type))
+					{
+						if ($status_type_id == $type_id)
+						{
+							unset($dcl_status_type[$key]);
+							break;
+						}
+					}
+				}
+			}
+
+			$objView->AddDef('filter', 'status', $statuses);
+		}
+
+		if (count($dcl_status_type) > 0)
+			$objView->AddDef('filter', 'statuses.dcl_status_type', $dcl_status_type);
+
 		if ($dateFrom != '' || $dateTo != '')
 		{
 			if ($dateFrom != '')
@@ -576,13 +696,35 @@ class boTickets
 				array('ticketid', 'responsible', 'product', 'account', 'status', 'contact', 'contactphone', 'summary'));
 
 		if (count($groups) > 0)
+		{
+			reset($groups);
+			while (list($key, $groupField) = each($groups))
+			{
+				if ($groupField == 'priorities.name')
+					$groups[$key] = 'priorities.weight';
+				else if ($groupField == 'severities.name')
+					$groups[$key] = 'severities.weight';
+			}
+
 			$objView->AddDef('groups', '', $groups);
+		}
 
 		if (count($columnhdrs) > 0)
 			$objView->AddDef('columnhdrs', '', $columnhdrs);
 
 		if (count($order) > 0)
+		{
+			reset($order);
+			while (list($key, $orderField) = each($order))
+			{
+				if ($orderField == 'priorities.name')
+					$order[$key] = 'priorities.weight';
+				else if ($orderField == 'severities.name')
+					$order[$key] = 'severities.weight';
+			}
+
 			$objView->AddDef('order', '', $order);
+		}
 		else
 			$objView->AddDef('order', '', array('ticketid'));
 
@@ -597,73 +739,10 @@ class boTickets
 		else
 			$objView->title = STR_TCK_TICKETSEARCHRESULTS;
 
-		$obj = CreateObject('dcl.htmlView');
+		$obj = CreateObject('dcl.htmlTicketResults');
 		$obj->Render($objView);
 	}
 
-	function SendNewMailMsg($obj)
-	{
-		global $dcl_info;
-
-		if ($dcl_info['DCL_SMTP_ENABLED'] != 'Y' || !is_object($obj))
-			return;
-
-		$objPersonnel = CreateObject('dcl.dbPersonnel');
-		$objPersonnel->Connect();
-		$objPersonnel2 = CreateObject('dcl.dbPersonnel');
-		$objPersonnel2->Connect($objPersonnel->conn);
-
-		$mailFrom = '';
-		if ($objPersonnel->Load($GLOBALS['DCLID']) != -1)
-			$mailFrom = 'From: ' . $objPersonnel->firstNameLast . ' <' . $objPersonnel->email . '>';
-
-		if ($objPersonnel->Load($obj->responsible) == -1)
-			return;
-
-		if ($objPersonnel2->Load($obj->createdby) == -1)
-			return;
-
-		if ($objPersonnel->email == '')
-			return;
-
-		$mailMsg = STR_BO_TICKETMAILMSG . phpCrLf . phpCrLf;
-		$mailMsg .= STR_TCK_TICKET . ': ' . $obj->ticketid . phpCrLf;
-		$mailMsg .= STR_TCK_OPENEDBY . ': ' . $objPersonnel2->lastNameFirst . phpCrLf;
-
-		$objProduct = CreateObject('dcl.dbProducts');
-		$objProduct->Connect($objPersonnel->conn);
-		$objProduct->Load($obj->product);
-		$mailMsg .= STR_TCK_PRODUCT . ': ' . $objProduct->name . phpCrLf;
-
-		$mailSubj = sprintf('[%d] %s', $obj->ticketid, $objProduct->name);
-
-		if ($this->account > 0)
-		{
-			$objAccount = CreateObject('dcl.dbAccounts');
-			$objAccount->Connect($objPersonnel->conn);
-			$objAccount->Load($obj->account);
-			$mailMsg .= STR_TCK_ACCOUNT . ': ' . $objAccount->name . phpCrLf;
-			$mailSubj .= ':' . $objAccount->name;
-		}
-
-		$mailMsg .= STR_TCK_CONTACT . ': ' . $obj->contact . phpCrLf . phpCrLf;
-		$mailSubj .= ':' . $objAccount->contact;
-		$link = $dcl_info['DCL_ROOT'] . 'main.php?menuAction=boTickets.view&ticketid=' . $obj->ticketid;
-		$mailMsg .= sprintf(STR_BO_SEEDETAILAT, $link);
-		$mailMsg .= phpCrLf . phpCrLf . STR_TCK_EMAILSIG;
-
-		$oMail = CreateObject('dcl.boSMTP');
-		$oMail->to = $objPersonnel->email;
-		$oMail->from = $GLOBALS['USEREMAIL'];
-		$oMail->subject = $mailSubj;
-		$oMail->body = $mailMsg;
-		$oMail->Send();
-
-		print('<p><center>');
-		PrintWithChocoFont(sprintf(STR_BO_MAILSENT, $objPersonnel->email));
-		print('</center><p>');
-	}
-
 	function showmy()
 	{
 		commonHeader();
