@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: class.boView.inc.php,v 1.5.4.3 2003/01/26 18:29:15 mdean Exp $
+ * $Id: class.boView.inc.php,v 1.5.4.14 2003/12/10 05:54:06 mdean Exp $
  *
  * Double Choco Latte - Source Configuration Management System
  * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
@@ -41,6 +41,7 @@ class boView
 	var $style;
 	var $startrow;
 	var $numrows;
+	var $m_oDB;
 
 	function boView()
 	{
@@ -60,6 +61,8 @@ class boView
 				'vfl',
 				'vs'
 			);
+
+		$this->m_oDB = null;
 	}
 
 	function ClearDef($def)
@@ -305,11 +308,14 @@ class boView
 		}
 	}
 
-	function AddDef($which, $field, $value = "")
+	function AddDef($which, $field, $value = '')
 	{
+		if ($this->table == 'workorders' && $field == 'account')
+			$field = 'dcl_wo_account.account_id';
+
 		if (is_array($value))
 		{
-			while (list($key, $qvalue) = each($value))
+			foreach ($value as $key => $qvalue)
 			{
 				if (substr($which, 0, 6) == 'filter')
 					$code = sprintf('$this->%s["%s"][] = "%s";', $which, $field, $qvalue);
@@ -329,10 +335,31 @@ class boView
 			eval($code);
 		}
 	}
+	
+	function RemoveDef($which, $field)
+	{
+		if ($this->table == 'workorders' && $field == 'account')
+			$field = 'dcl_wo_account.account_id';
+
+		if (substr($which, 0, 6) == 'filter')
+			$code = sprintf('unset($this->%s["%s"]);', $which, $field);
+		else
+			$code = sprintf('$this->%s = array();', $which);
+
+		eval($code);
+	}
+	
+	function ReplaceDef($which, $field, $value = '')
+	{
+		$this->RemoveDef($which, $field);
+		$this->AddDef($which, $field, $value);
+	}
 
 	// That's Comma Separated List :)
-	function GetCSLFromArray(&$arr, $appendTableForJoin = false)
+	function GetCSLFromArray(&$arr, $appendTableForJoin = false, $bProcessDates = false)
 	{
+		global $phpgw_baseline;
+
 		reset($arr);
 		$retVal = '';
 
@@ -345,10 +372,41 @@ class boView
 					if ($retVal != '')
 						$retVal .= ',';
 
-					if (strpos($field, '.') > 0)
-						$retVal .= $field; // He said they've already got one!
+					if ($bProcessDates)
+					{
+						if (strpos($field, '.') > 0)
+						{
+							list($sTable, $sField) = explode('.', $field);
+							$sRealTable = $sTable;
+						}
+						else
+						{
+							$sTable = $this->table;
+							$sRealTable = $sTable;
+							$sField = $field;
+						}
+
+						if (strlen($sTable) == 1 && ($sTable == 'a' || $sTable == 'b' || $sTable == 'c'))
+							$sRealTable = 'personnel';
+
+						if (!$this->m_oDB)
+							$this->m_oDB = new dclDB;
+
+						LoadSchema($sRealTable);
+						if ($phpgw_baseline[$sRealTable]['fd'][$sField]['type'] == 'timestamp')
+							$retVal .= $this->m_oDB->ConvertTimestamp($sTable . '.' . $sField, $sField);
+						else if ($phpgw_baseline[$sRealTable]['fd'][$sField]['type'] == 'date')
+							$retVal .= $this->m_oDB->ConvertDate($sTable . '.' . $sField, $sField);
+						else
+							$retVal .= $sTable . '.' . $sField;
+					}
 					else
-						$retVal .= $this->table . '.' . $field;
+					{
+						if (strpos($field, '.') > 0)
+							$retVal .= $field; // He said they've already got one!
+						else
+							$retVal .= $this->table . '.' . $field;
+					}
 				}
 			}
 			else
@@ -374,9 +432,6 @@ class boView
 				case 'priorities':
 					$join = 'workorders.priority=priorities.id';
 					break;
-				case 'accounts':
-					$join = 'workorders.account=accounts.id';
-					break;
 				case 'products':
 					$join = 'workorders.product=products.id';
 					break;
@@ -401,6 +456,18 @@ class boView
 				case 'personnel c':
 					$join = 'workorders.createby=c.id';
 					break;
+				case 'dcl_status_type':
+					$join = '(workorders.status = statuses.id AND statuses.dcl_status_type = dcl_status_type.dcl_status_type_id)';
+					break;
+				case 'dcl_wo_type':
+					$join = 'workorders.wo_type_id = dcl_wo_type.wo_type_id';
+					break;
+				case 'accounts':
+					$join = 'dcl_wo_account.account_id = accounts.id';
+					break;
+				case 'dcl_wo_account':
+					$join = 'workorders.jcn = dcl_wo_account.wo_id AND workorders.seq = dcl_wo_account.seq';
+					break;
 			}
 		}
 		elseif ($this->table == 'tickets')
@@ -434,6 +501,9 @@ class boView
 				case 'personnel c':
 					$join = 'tickets.createdby=c.id';
 					break;
+				case 'dcl_status_type':
+					$join = '(tickets.status = statuses.id AND statuses.dcl_status_type = dcl_status_type.dcl_status_type_id)';
+					break;
 			}
 		}
 		elseif ($this->table == 'dcl_projects')
@@ -448,12 +518,35 @@ class boView
 					break;
 			}
 		}
+		elseif ($this->table == 'dcl_session')
+		{
+			switch ($table)
+			{
+				case 'personnel':
+					$join = 'dcl_session.personnel_id = personnel.id';
+					break;
+			}
+		}
+		elseif ($this->table == 'personnel')
+		{
+			switch ($table)
+			{
+				case 'departments':
+					$join = 'personnel.department = departments.id';
+					break;
+				case 'personnel a':
+					$join = 'personnel.reportto = a.id';
+					break;
+			}
+		}
 
 		return $join;
 	}
 
 	function AppendJoins(&$arr)
 	{
+		global $dcl_info;
+
 		if (count($arr) > 0)
 		{
 			reset($arr);
@@ -462,7 +555,8 @@ class boView
 			while (list($key, $field) = each($arr))
 			{
 				// If field is an array, then it contains values - $key is our real field
-				if (is_array($field))
+				$bIsValues = is_array($field);
+				if ($bIsValues)
 					$field = $key;
 
 				if (strpos($field, '.') > 0)
@@ -470,9 +564,8 @@ class boView
 					list($table, $tablefield) = explode('.', $field);
 					if ($table == $this->table)
 						continue;
-						
-					$iJoinType = 1; // 1 = normal, 2 = left
 
+					$iJoinType = 1; // 1 = normal, 2 = left
 					switch ($table)
 					{
 						case 'a':
@@ -486,20 +579,44 @@ class boView
 							break;
 						case 'responsible':
 							$table = 'personnel a';
-							$arr[$i] = str_replace('responsible', 'a', $arr[$i]);
+							if ($bIsValues)
+							{
+								$arr[str_replace('responsible', 'a', $key)] = $arr[$key];
+								unset($arr[$key]);
+							}
+							else
+								$arr[$i] = str_replace('responsible', 'a', $arr[$i]);
 							break;
 						case 'closedby':
 							$table = 'personnel b';
-							$arr[$i] = str_replace('closedby', 'b', $arr[$i]);
+							if ($bIsValues)
+							{
+								$arr[str_replace('closedby', 'b', $key)] = $arr[$key];
+								unset($arr[$key]);
+							}
+							else
+								$arr[$i] = str_replace('closedby', 'b', $arr[$i]);
 							break;
 						case 'createdby':
 						case 'createby':
-							$arr[$i] = str_replace($table, 'c', $arr[$i]);
+							if ($bIsValues)
+							{
+								$arr[str_replace($table, 'b', $key)] = $arr[$key];
+								unset($arr[$key]);
+							}
+							else
+								$arr[$i] = str_replace($table, 'c', $arr[$i]);
 							$table = 'personnel c';
 							break;
 						case 'reportto':
 							$table = 'personnel a';
-							$arr[$i] = str_replace('reportto', 'a', $arr[$i]);
+							if ($bIsValues)
+							{
+								$arr[str_replace('reportto', 'a', $key)] = $arr[$key];
+								unset($arr[$key]);
+							}
+							else
+								$arr[$i] = str_replace('reportto', 'a', $arr[$i]);
 							break;
 						case 'accounts':
 							$iJoinType = 2;
@@ -513,16 +630,29 @@ class boView
 						case 'dcl_product_module':
 							$iJoinType = 2;
 							break;
+						case 'dcl_wo_account':
+							$iJoinType = 2;
+							break;
 					}
 
 					if (!IsSet($this->joins[$table]))
 					{
 						// work orders are associated to projects in the projectmap table
 						// so append it here - we don't want it in the selected columns
+
+						// Ensure we join dcl_wo_account before accounts
 						if ($table == 'dcl_projects')
 							$this->joins['projectmap'] = 2;
-						
-						$this->joins[$table] = $iJoinType;
+						else if ($this->table == 'workorders' && $table == 'accounts' && !isset($this->joins['dcl_wo_account']))
+							$this->joins['dcl_wo_account'] = 2;
+
+						if (!($dcl_info['DCL_WO_SECONDARY_ACCOUNTS_ENABLED'] == 'Y' &&
+							$this->table == 'workorders' &&
+							($table == 'dcl_wo_account' || $table == 'accounts') &&
+							!in_array('accounts.name', $this->order) &&
+							!in_array('accounts.name', $this->groups) &&
+							!in_array('accounts.name', $this->columns)))
+							$this->joins[$table] = $iJoinType;
 					}
 				}
 
@@ -533,10 +663,8 @@ class boView
 
 	function GetSQL($bCount = false)
 	{
-		global $dcl_domain, $dcl_domain_info;
+		global $dcl_domain, $dcl_domain_info, $dcl_info;
 
-		// Check for joins - currently we'll just look at the order by and groups since
-		// we don't really get that complex anywhere except for searches
 		$this->joins = array();
 		$this->AppendJoins($this->order);
 		$this->AppendJoins($this->groups);
@@ -555,18 +683,43 @@ class boView
 			if (count($this->columns) > 0 || count($this->groups) > 0)
 			{
 				if (count($this->groups) > 0)
-					$sql .= $this->GetCSLFromArray($this->groups, true);
+				{
+					$aGroups = $this->groups;
+					reset($aGroups);
+					while (list($key, $group) = each($aGroups))
+					{
+						// If we group by weight, we want to display the name while ordering by weight
+						if ($group == 'priorities.weight')
+							$aGroups[$key] = 'priorities.name';
+						else if ($group == 'severities.weight')
+							$aGroups[$key] = 'severities.name';
+					}
+
+					$sql .= $this->GetCSLFromArray($aGroups, true);
+				}
 
 				if (count($this->columns) > 0)
 				{
 					if (count($this->groups) > 0)
 						$sql .= ",";
 
-					$sql .= $this->GetCSLFromArray($this->columns, true);
+					$sql .= $this->GetCSLFromArray($this->columns, true, true);
 				}
 			}
 			else
 				$sql .= '*';
+				
+			if ($this->table == 'workorders' && $dcl_info['DCL_WO_SECONDARY_ACCOUNTS_ENABLED'] == 'Y')
+			{
+				// If we show account, but don't group by it, then we will want to display an icon to show
+				// the extra accounts.  This count will determine if we need to display the marker for more info
+				// and will be left out of the final rendering by htmlView
+				if (in_array('accounts.name', $this->columns))
+				{
+					$sql .= ', (select count(*) from dcl_wo_account where wo_id = workorders.jcn And seq = workorders.seq) As _num_accounts_';
+				}
+			}
+
 		}
 
 		$sql .= ' FROM ' . $this->table;
@@ -578,6 +731,25 @@ class boView
 		{
 			reset($this->joins);
 			$joinsql = '';
+
+			// Ensure these join in the proper order
+			if (isset($this->joins['dcl_status_type']))
+			{
+				if (isset($this->joins['statuses']))
+				{
+					$statusesSQL = $this->joins['statuses'];
+					unset($this->joins['statuses']);
+				}
+				else
+					$statusesSQL = ' JOIN statuses ON ' . $this->GetJoinForTable('statuses');
+
+				$typesSQL = $this->joins['dcl_status_type'];
+				unset($this->joins['dcl_status_type']);
+
+				$this->joins['statuses'] = $statusesSQL;
+				$this->joins['dcl_status_type'] = $typesSQL;
+			}
+
 			while (list($table, $iJoinType) = each($this->joins))
 			{
 				if ($iJoinType == 2)
@@ -591,6 +763,12 @@ class boView
 			$sql .= $joinsql . ' ';
 		}
 
+		$productSQL = '';
+		$moduleSQL = '';
+		$deptSQL = '';
+		$responsibleSQL = '';
+		$createbySQL = '';
+		$closedbySQL = '';
 		if (count($this->filter) > 0)
 		{
 			if ($bDoneDidWhere == false)
@@ -609,17 +787,139 @@ class boView
 				if (strpos($field, '.') < 1)
 					$field = $this->table . '.' . $field;
 
-				if ($bFirst == false)
-					$sql .= ' AND ';
+				if (eregi('^.*\.product', $field))
+				{
+					if (count($values) == 1)
+						$productSQL = "($field=" . $this->GetCSLFromArray($values) . ')';
+					else
+						$productSQL = "($field in (" . $this->GetCSLFromArray($values) . '))';
+				}
+				else if (eregi('^.*\.module_id', $field))
+				{
+					if (count($values) == 1)
+						$moduleSQL = "($field=" . $this->GetCSLFromArray($values) . ')';
+					else
+						$moduleSQL = "($field in (" . $this->GetCSLFromArray($values) . '))';
+				}
+				else if (eregi('^.*\.department', $field))
+				{
+					if (count($values) == 1)
+						$deptSQL = "($field=" . $this->GetCSLFromArray($values) . ')';
+					else
+						$deptSQL = "($field in (" . $this->GetCSLFromArray($values) . '))';
+				}
+				else if (eregi('^.*\.responsible', $field))
+				{
+					if (count($values) == 1)
+						$responsibleSQL = "($field=" . $this->GetCSLFromArray($values) . ')';
+					else
+						$responsibleSQL = "($field in (" . $this->GetCSLFromArray($values) . '))';
+				}
+				else if (eregi('^.*\.create[d]?by', $field))
+				{
+					if (count($values) == 1)
+						$createbySQL = "($field=" . $this->GetCSLFromArray($values) . ')';
+					else
+						$createbySQL = "($field in (" . $this->GetCSLFromArray($values) . '))';
+				}
+				else if (eregi('^.*\.closedby', $field))
+				{
+					if (count($values) == 1)
+						$closedbySQL = "($field=" . $this->GetCSLFromArray($values) . ')';
+					else
+						$closedbySQL = "($field in (" . $this->GetCSLFromArray($values) . '))';
+				}
+				else if ($dcl_info['DCL_WO_SECONDARY_ACCOUNTS_ENABLED'] == 'Y' &&
+						$this->table == 'workorders' &&
+						!in_array('accounts.name', $this->order) &&
+						!in_array('accounts.name', $this->groups) &&
+						!in_array('accounts.name', $this->columns) &&
+						eregi('^.*\.account', $field))
+				{
+					// Multi-account filter only does subselect - not MySQL compatible yet
+					if ($bFirst == false)
+						$sql .= ' AND ';
 
-				$bFirst = false;
-				if (count($values) == 1)
-					$sql .= "($field=" . $this->GetCSLFromArray($values) . ')';
+					$bFirst = false;
+
+					$sql .= "((workorders.jcn in (select wo_id from dcl_wo_account where account_id in (" . $this->GetCSLFromArray($values) . ")))";
+					$sql .= " AND (workorders.seq in (select seq from dcl_wo_account where workorders.jcn = wo_id And account_id in (" . $this->GetCSLFromArray($values) . "))";
+					$sql .= '))';
+				}
 				else
-					$sql .= "($field in (" . $this->GetCSLFromArray($values) . '))';
+				{
+					if ($bFirst == false)
+						$sql .= ' AND ';
+
+					$bFirst = false;
+					if (count($values) == 1)
+						$sql .= "($field=" . $this->GetCSLFromArray($values) . ')';
+					else
+						$sql .= "($field in (" . $this->GetCSLFromArray($values) . '))';
+				}
 			}
 		}
 
+		// Now handle product and module specially because module is exclusive to product, but
+		// we may still have other products where they don't filter by module
+		if ($productSQL != '' && $moduleSQL != '')
+		{
+			if ($bFirst == false)
+				$sql .= ' AND ';
+
+			$bFirst = false;
+			$sql .= '(' . $productSQL . ' OR ' . $moduleSQL . ')';
+		}
+		else if ($productSQL != '')
+		{
+			if ($bFirst == false)
+				$sql .= ' AND ';
+
+			$bFirst = false;
+			$sql .= $productSQL;
+		}
+		else if ($moduleSQL != '')
+		{
+			if ($bFirst == false)
+				$sql .= ' AND ';
+
+			$bFirst = false;
+			$sql .= $moduleSQL;
+		}
+
+		$arrPersonnel = array();
+		if ($deptSQL != '')
+			$arrPersonnel[] = $deptSQL;
+		if ($responsibleSQL != '')
+			$arrPersonnel[] = $responsibleSQL;
+		if ($createbySQL != '')
+			$arrPersonnel[] = $createbySQL;
+		if ($closedbySQL != '')
+			$arrPersonnel[] = $closedbySQL;
+
+		if (count($arrPersonnel) > 0)
+		{
+			if ($bFirst == false)
+				$sql .= ' AND ';
+
+			$bFirst = false;
+
+			if (count($arrPersonnel) > 1)
+			{
+				$sql .= '(';
+				for ($i = 0; $i < count($arrPersonnel); $i++)
+				{
+					if ($i > 0)
+						$sql .= ' OR ';
+
+					$sql .= $arrPersonnel[$i];
+				}
+				$sql .= ')';
+			}
+			else
+				$sql .= $arrPersonnel[0];
+		}
+
 		if (count($this->filternot) > 0)
 		{
 			if ($bDoneDidWhere == false)
@@ -725,19 +1025,28 @@ class boView
 			$sql .= ')';
 		}
 
+		if ($this->table == 'workorders' && $dcl_info['DCL_WO_SECONDARY_ACCOUNTS_ENABLED'] == 'Y')
+		{
+			// If we group by account, we'll show join the whole lot together.  This will cause a work order
+			// with n accounts to appear in the report n times.  Otherwise, if we only sort or show the account
+			// column, we'll get the first account (in order) and display a link to show the other accounts
+			// as needed
+			if (in_array('accounts.name', $this->columns))
+			{
+				$sql .= ' And (dcl_wo_account.account_id is null Or dcl_wo_account.account_id = ';
+				$sql .= '(Select min(account_id) From dcl_wo_account where wo_id = workorders.jcn And seq = workorders.seq))';
+			}
+		}
+
 		if (!$bCount && (count($this->order) > 0 || count($this->groups) > 0))
 		{
 			$sql .= ' ORDER BY ';
-			if (count($this->groups) > 0)
-				$sql .= $this->GetCSLFromArray($this->groups);
-
-			if (count($this->order) > 0)
-			{
-				if (count($this->groups) > 0)
-					$sql .= ',';
-
-				$sql .= $this->GetCSLFromArray($this->order);
-			}
+			if (count($this->order) > 0 || count($this->groups) > 0)
+				$sql .= $this->GetCSLFromArray(array_merge($this->groups, $this->order), true);
+			else if (count($this->groups) > 0)
+				$sql .= $this->GetCSLFromArray($this->groups, true);
+			else
+				$sql .= $this->GetCSLFromArray($this->order, true);
 		}
 
 		return $sql;
