@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: class.boWatches.inc.php,v 1.4.2.2.2.9 2003/01/29 05:18:20 mdean Exp $
+ * $Id: class.boWatches.inc.php,v 1.4.2.2.2.18 2004/01/04 21:15:32 mdean Exp $
  *
  * Double Choco Latte - Source Configuration Management System
  * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
@@ -227,7 +227,7 @@ class boWatches
 		$oMail = CreateObject('dcl.boSMTP');
 		$oMail->isHtml = ($dcl_info['DCL_WO_NOTIFICATION_HTML'] == 'Y');
 
-		$t = CreateObject('dcl.Template');
+		$t = CreateObject('dcl.DCLTemplate');
 		$t->set_file(array('hForm' => 'templates/custom/' . $dcl_info['DCL_WO_EMAIL_TEMPLATE']));
 		$t->set_block('hForm', 'timecards', 'hTimecards');
 		$t->set_var('hTimecards');
@@ -256,8 +256,9 @@ class boWatches
 		$t->set_var('TXT_CONTACTPHONE', STR_WO_CONTACTPHONE);
 		$t->set_var('TXT_NOTES', STR_WO_NOTES);
 		$t->set_var('TXT_DESCRIPTION', STR_WO_DESCRIPTION);
-		$t->set_var('TXT_MODULE', 'Module');
+		$t->set_var('TXT_MODULE', STR_CMMN_MODULE);
 		$t->set_var('TXT_PROJECT', STR_WO_PROJECT);
+		$t->set_var('TXT_TYPE', STR_WO_TYPE);
 
 		$t->set_var('VAL_WOID', $obj->jcn);
 		$t->set_var('VAL_SEQ', $obj->seq);
@@ -303,11 +304,15 @@ class boWatches
 		$objSeverity->Connect($obj->conn);
 		$objProduct = CreateObject('dcl.dbProducts');
 		$objProduct->Connect($obj->conn);
+		$objType = CreateObject('dcl.dbWorkOrderType');
+		$objType->Connect($obj->conn);
 
 		$objPersonnel->Load($obj->responsible);
 		$t->set_var('VAL_RESPONSIBLE', $objPersonnel->short);
 		$objPersonnel->Load($obj->createby);
 		$t->set_var('VAL_OPENEDBY', $objPersonnel->short);
+		$objType->Load($obj->wo_type_id);
+		$t->set_var('VAL_TYPE', $objType->type_name);
 
 		if ($objStatus->GetStatusType($obj->status) == 2)
 		{
@@ -327,12 +332,19 @@ class boWatches
 		$t->set_var('VAL_PRODUCT', $objProduct->name);
 		$t->set_var('VAL_STATUS', $objStatus->name);
 
-		if ($obj->account > 0)
+		$objAccount = CreateObject('dcl.dbWorkOrderAccount');
+		$objAccount->Connect($obj->conn);
+		if ($objAccount->Load($obj->jcn, $obj->seq) != -1)
 		{
-			$objAccount = CreateObject('dcl.dbAccounts');
-			$objAccount->Connect($obj->conn);
-			$objAccount->Load($obj->account);
-			$t->set_var('VAL_ACCOUNT', $objAccount->name);
+			$sAccounts = '';
+			do
+			{
+				$objAccount->GetRow();
+				$sAccounts .= $objAccount->account_name . '; ';
+			}
+			while ($objAccount->next_record());
+
+			$t->set_var('VAL_ACCOUNT', $sAccounts);
 		}
 		else
 			$t->set_var('VAL_ACCOUNT', '');
@@ -429,16 +441,18 @@ class boWatches
 
 		$objWtch = CreateObject('dcl.dbWatches');
 		$objWtch->Connect();
-		$query = "select distinct whoid from watches where actions in ($actions) and (";
+		$query = 'select distinct email from personnel ' . $objWtch->JoinKeyword . ' watches ON id=whoid ';
+		$query .= 'LEFT JOIN dcl_wo_account ON typeid = 6 AND wo_id = ' . $obj->jcn;
+		$query .= ' AND dcl_wo_account.seq = ' . $obj->seq . ' AND whatid1 = account_id ';;
+		$query .= "where id = whoid AND actions in ($actions) and (";
 		$query .= sprintf('(typeid=1 AND whatid1=%d)', $obj->product);
 		if ($projectID != -1)
 			$query .= sprintf(' or (typeid=2 and whatid1=%d)', $projectID);
 		$query .= sprintf(' or (typeid=3 and whatid1=%d and whatid2 in (0,%d))', $obj->jcn, $obj->seq);
-
-		if ($obj->account > 0)
-			$query .= sprintf(' or (typeid=6 and whatid1=%d)', $obj->account);
+		$query .= ' or (typeid = 6 and whatid1 = account_id)';
 
 		$query .= sprintf(') AND whoid != %d', $GLOBALS['DCLID']);
+		$query .= " AND active = 'Y' AND email IS NOT NULL AND email != ''";
 
 		$arrEmail = array();
 		$mailFrom = '';
@@ -449,7 +463,7 @@ class boWatches
 			if ($objPersonnel->active == 'Y' && !IsSet($arrEmail[$objPersonnel->email]))
 				$arrEmail[$objPersonnel->email] = 1;
 
-		if ($objPersonnel->Load($obj->createby) != -1)
+		if ($obj->createby != $GLOBALS['DCLID'] && $objPersonnel->Load($obj->createby) != -1)
 			if ($objPersonnel->active == 'Y' && $objPersonnel->email != '' && !IsSet($arrEmail[$objPersonnel->email]))
 				$arrEmail[$objPersonnel->email] = 1;
 
@@ -457,13 +471,18 @@ class boWatches
 		{
 			while ($objWtch->next_record())
 			{
-				if ($objPersonnel->Load($objWtch->f(0)) != -1)
-					if ($objPersonnel->active == 'Y' && !IsSet($arrEmail[$objPersonnel->email]))
-						$arrEmail[$objPersonnel->email] = 1;
+				$arrEmail[$objWtch->f(0)] = 1;
 			}
 		}
+
+		if (count($arrEmail) == 0)
+			return;
+
 		// Here we go!
 		$toAddr = '';
+		if ($objPriority->weight == 1)
+			$oMail->AddHeader('X-Priority: 1');
+
 		$oMail->from = $mailFrom;
 		$oMail->subject = sprintf('[%s %d-%d] %s', STR_WO_JCN, $obj->jcn, $obj->seq, $obj->summary);
 		$oMail->body = $t->parse('out', 'hForm');
@@ -498,7 +517,7 @@ class boWatches
 		$oMail = CreateObject('dcl.boSMTP');
 		$oMail->isHtml = ($dcl_info['DCL_TCK_NOTIFICATION_HTML'] == 'Y');
 
-		$t = CreateObject('dcl.Template');
+		$t = CreateObject('dcl.DCLTemplate');
 		$t->set_file(array('hForm' => 'templates/custom/' . $dcl_info['DCL_TCK_EMAIL_TEMPLATE']));
 		$t->set_block('hForm', 'resolutions', 'hResolutions');
 		$t->set_var('hResolutions');
@@ -515,7 +534,7 @@ class boWatches
 		$t->set_var('TXT_PRIORITY', STR_TCK_PRIORITY);
 		$t->set_var('TXT_TYPE', STR_TCK_TYPE);
 		$t->set_var('TXT_PRODUCT', STR_TCK_PRODUCT);
-		$t->set_var('TXT_MODULE', 'Module');
+		$t->set_var('TXT_MODULE', STR_CMMN_MODULE);
 		$t->set_var('TXT_VERSION', STR_TCK_VERSION);
 		$t->set_var('TXT_ACCOUNT', STR_TCK_ACCOUNT);
 		$t->set_var('TXT_CONTACT', STR_TCK_CONTACT);
@@ -669,13 +688,16 @@ class boWatches
 		}
 		// Here we go!
 		$toAddr = '';
+		if ($objPriority->weight == 1)
+			$oMail->AddHeader('X-Priority: 1');
+
 		$oMail->from = $mailFrom;
-		$oMail->subject = sprintf('[%d] %s', $obj->ticketid, $obj->summary);
+		$oMail->subject = sprintf('[%s #%d] %s', STR_TCK_TICKET, $obj->ticketid, $obj->summary);
 		$oMail->body = $t->parse('out', 'hForm');
 		$oMail->to = array();
 		while (list($email, $junk) = each($arrEmail))
 		{
-			$oMail->to[] = $email;
+			$oMail->to[] = '<' . $email . '>';
 			if ($toAddr != '')
 				$toAddr .= ', ';
 			$toAddr .= $email;
