@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: class.boWorkorders.inc.php,v 1.8.2.3.2.7 2003/01/29 05:46:40 mdean Exp $
+ * $Id: class.boWorkorders.inc.php,v 1.8.2.3.2.20 2003/12/10 05:54:06 mdean Exp $
  *
  * Double Choco Latte - Source Configuration Management System
  * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
@@ -91,6 +91,41 @@ class boWorkorders
 		$objWorkorder->createby = $GLOBALS['DCLID'];
 		$objWorkorder->Add();
 
+		// multiple accounts?
+		if ($dcl_info['DCL_WO_SECONDARY_ACCOUNTS_ENABLED'] == 'Y')
+		{
+			if (IsSet($GLOBALS['secaccounts']) && $GLOBALS['secaccounts'] != '')
+			{
+				$aAccounts = explode(',', $GLOBALS['secaccounts']);
+				if (count($aAccounts) > 0)
+				{
+					$oWOA = CreateObject('dcl.dbWorkOrderAccount');
+					$oWOA->Connect();
+					$oWOA->wo_id = $objWorkorder->jcn;
+					$oWOA->seq = $objWorkorder->seq;
+
+					for ($i = 0; $i < count($aAccounts); $i++)
+					{
+						if ($aAccounts[$i] > 0)
+						{
+							$oWOA->account_id = $aAccounts[$i];
+							$oWOA->Add();
+						}
+					}
+				}
+			}
+		}
+		else if (IsSet($GLOBALS['account']) && $GLOBALS['account'] > 0)
+		{
+			$oWOA = CreateObject('dcl.dbWorkOrderAccount');
+			$oWOA->Connect();
+			$oWOA->wo_id = $objWorkorder->jcn;
+			$oWOA->seq = $objWorkorder->seq;
+			$oWOA->account_id = $GLOBALS['account'];
+			$oWOA->Add();
+		}
+
+		// add to a project?
 		if (IsSet($GLOBALS['projectid']) && $GLOBALS['projectid'] > 0 && $GLOBALS['SEC'] >= $dcl_info['DCL_ASSIGN_WO'])
 		{
 			$objPM = CreateObject('dcl.dbProjectmap');
@@ -108,6 +143,25 @@ class boWorkorders
 			$objPM->Add();
 		}
 
+		// upload a file attachment?
+		if (IsSet($GLOBALS['userfile']) && $GLOBALS['userfile'] != 'none')
+		{
+			if (!((IsSet($HTTP_POST_VARS['userfile']) && $HTTP_POST_VARS['userfile'] == $GLOBALS['userfile']) ||
+				(IsSet($HTTP_GET_VARS['userfile']) && $HTTP_GET_VARS['userfile'] == $GLOBALS['userfile']) ||
+				(IsSet($HTTP_COOKIE_VARS['userfile']) && $HTTP_COOKIE_VARS['userfile'] == $GLOBALS['userfile'])))
+			{
+				$o = CreateObject('dcl.boFile');
+				$o->iType = ATTACHMENT_WORKORDER;
+				$o->iKey1 = $objWorkorder->jcn;
+				$o->iKey2 = $objWorkorder->seq;
+				$o->sFileName = is_array($GLOBALS['userfile']) ? $GLOBALS['userfile']['name'] : $GLOBALS['userfile_name'];
+				$o->sTempFileName = is_array($GLOBALS['userfile']) ? $GLOBALS['userfile']['tmp_name'] : $GLOBALS['userfile'];
+				$o->sRoot = $dcl_info['DCL_FILE_PATH'] . '/attachments';
+				$o->Upload();
+			}
+		}
+
+		// copied from ticket?
 		if (IsSet($GLOBALS['ticketid']) && $GLOBALS['ticketid'] > 0)
 		{
 			$oTR = CreateObject('dcl.dbTicketresolutions');
@@ -142,6 +196,8 @@ class boWorkorders
 
 	function dbmodifyjcn()
 	{
+		global $dcl_info;
+		
 		commonHeader();
 		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_MOD_WO']))
 			return PrintPermissionDenied();
@@ -152,7 +208,7 @@ class boWorkorders
 
 		$objWorkorder->product = $GLOBALS['product'];
 		$objWorkorder->module_id = $GLOBALS['module_id'];
-		$objWorkorder->account = $GLOBALS['account'];
+		$objWorkorder->wo_type_id = $GLOBALS['wo_type_id'];
 		$objWorkorder->deadlineon = $GLOBALS['deadlineon'];
 		$objWorkorder->eststarton = $GLOBALS['eststarton'];
 
@@ -172,6 +228,46 @@ class boWorkorders
 
 		$objWorkorder->Edit();
 
+		// secondary accounts?
+		if ($dcl_info['DCL_WO_SECONDARY_ACCOUNTS_ENABLED'] == 'Y' && IsSet($GLOBALS['secaccounts']))
+		{
+			// Delete existing references
+			$oWOA = CreateObject('dcl.dbWorkOrderAccount');
+			$oWOA->Connect();
+			$oWOA->DeleteByWorkOrder($objWorkorder->jcn, $objWorkorder->seq);
+
+			// Add the new ones - TODO: load accounts and apply diff instead of blindly wiping and re-adding everything
+			$aAccounts = explode(',', $GLOBALS['secaccounts']);
+			if (count($aAccounts) > 0)
+			{
+				$oWOA->wo_id = $objWorkorder->jcn;
+				$oWOA->seq = $objWorkorder->seq;
+
+				for ($i = 0; $i < count($aAccounts); $i++)
+				{
+					if ($aAccounts[$i] > 0)
+					{
+						$oWOA->account_id = $aAccounts[$i];
+						$oWOA->Add();
+					}
+				}
+			}
+		}
+		else if (IsSet($GLOBALS['account']))
+		{
+			$oWOA = CreateObject('dcl.dbWorkOrderAccount');
+			$oWOA->Connect();
+			$oWOA->DeleteByWorkOrder($objWorkorder->jcn, $objWorkorder->seq);
+
+			if ($GLOBALS['account'] > 0)
+			{
+				$oWOA->wo_id = $objWorkorder->jcn;
+				$oWOA->seq = $objWorkorder->seq;
+				$oWOA->account_id = $GLOBALS['account'];
+				$oWOA->Add();
+			}
+		}
+
 		$objWtch = CreateObject('dcl.boWatches');
 		$objWtch->sendNotification($objWorkorder, '4');
 
@@ -200,9 +296,19 @@ class boWorkorders
 		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_DEL_WO']))
 			return PrintPermissionDenied();
 
+		// Remove from projects
 		$objPM = CreateObject('dcl.boProjects');
 		$objPM->dbunmap($GLOBALS['jcn'], $GLOBALS['seq'], true);
+		
+		// Remove secondary accounts
+		if ($dcl_info['DCL_WO_SECONDARY_ACCOUNTS_ENABLED'] == 'Y')
+		{
+			$oWOA = CreateObject('dcl.dbWorkOrderAccount');
+			$oWOA->Connect();
+			$oWOA->DeleteByWorkOrder($GLOBALS['jcn'], $GLOBALS['seq']);
+		}
 
+		// Remove the work order entry - also does time cards
 		$obj = CreateObject('dcl.dbWorkorders');
 		$obj->Connect();
 		$obj->jcn = $GLOBALS['jcn'];
@@ -210,6 +316,11 @@ class boWorkorders
 
 		$obj->Delete();
 
+		// Remove account references
+		$oWOA = CreateObject('dcl.dbWorkOrderAccount');
+		$oWOA->Connect();
+		$oWOA->DeleteByWorkOrder($objWorkorder->jcn, $objWorkorder->seq);
+
 		// Remove all attachments
 		$attachPath = $dcl_info['DCL_FILE_PATH'] . '/attachments/wo/' . substr($GLOBALS['jcn'], -1) . '/' . $GLOBALS['jcn'] . '/' . $GLOBALS['seq'] . '/';
 		if ($hDir = @opendir($attachPath))
@@ -231,13 +342,6 @@ class boWorkorders
 		$objMy->showMy();
 	}
 
-	function search()
-	{
-		commonHeader();
-		$obj = CreateObject('dcl.htmlWOSearches');
-		$obj->Show();
-	}
-
 	function viewjcn()
 	{
 		commonHeader();
@@ -272,14 +376,14 @@ class boWorkorders
 			array(STR_WO_JCN, STR_WO_SEQ, STR_WO_RESPONSIBLE, STR_WO_PRODUCT,
 				STR_WO_STATUS, STR_WO_ESTSTART, STR_WO_DEADLINE, STR_WO_ETCHOURS, STR_WO_ACTHOURS, STR_WO_SUMMARY));
 
-		$objHV = CreateObject('dcl.htmlView');
+		$objHV = CreateObject('dcl.htmlWorkOrderResults');
 		$objHV->Render($objView);
 	}
 
 	function dbsearch()
 	{
-		global $responsible, $createby, $closedby, $personnel, $product;
-		global $severity, $priority, $status, $account;
+		global $responsible, $createby, $closedby, $personnel, $product, $project, $module_id, $wo_type_id, $department;
+		global $severity, $priority, $status, $dcl_status_type, $account;
 		global $createdon, $closedon, $statuson, $lastactionon, $deadlineon;
 		global $eststarton, $estendon, $starton, $dateFrom, $dateTo;
 		global $summary, $notes, $description, $searchText;
@@ -310,23 +414,125 @@ class boWorkorders
 		else
 			$order = array();
 
-		if (count($personnel) > 0)
+		if (count($personnel) > 0 || count($department) > 0)
 		{
 			$fieldList = array('responsible', 'createby', 'closedby');
+			$bStrippedDepartments = false;
+			$pers_sel = array();
 			while (list($key, $field) = each($fieldList))
 			{
 				if ($$field == '1')
-					$objView->AddDef('filter', $field, $personnel);
+				{
+					if (count($personnel) > 0)
+					{
+						if (!$bStrippedDepartments)
+						{
+							$bStrippedDepartments = true;
+
+							// Have actual personnel?  If so, only set personnel for their associated departments instead of the department
+							// then unset the department from the array
+							reset($personnel);
+							while (list(, $encoded_pers) = each($personnel))
+							{
+								list($dpt_id, $pers_id) = explode(',', $encoded_pers);
+								$pers_sel[count($pers_sel)] = $pers_id;
+								if (count($department) > 0 && in_array($dpt_id, $department))
+								{
+									reset($department);
+									while(list($key, $department_id) = each($department))
+									{
+										if ($department_id == $dpt_id)
+										{
+											unset($department[$key]);
+											break;
+										}
+									}
+								}
+							}
+						}
+
+						$objView->AddDef('filter', $field, $pers_sel);
+					}
+
+					if (count($department) > 0)
+						$objView->AddDef('filter', $field . '.department', $department);
+				}
 			}
 		}
 
-		$fieldList = array('product', 'priority', 'severity', 'account', 'status');
+		$fieldList = array('priority', 'severity', 'wo_type_id');
 		while (list($key, $field) = each($fieldList))
 		{
 			if (count($$field) > 0)
 				$objView->AddDef('filter', $field, $$field);
 		}
 
+		if (count($module_id) > 0)
+		{
+			// Have modules?  If so, only set module IDs for their associated products instead of the product ID
+			// then unset the product id from the array
+			reset($module_id);
+			$module = array();
+			while (list(, $encoded_mod) = each($module_id))
+			{
+				list($mod_prod_id, $mod_id) = explode(',', $encoded_mod);
+				$module[count($module)] = $mod_id;
+				if (count($product) > 0 && in_array($mod_prod_id, $product))
+				{
+					reset($product);
+					while(list($key, $product_id) = each($product))
+					{
+						if ($product_id == $mod_prod_id)
+						{
+							unset($product[$key]);
+							break;
+						}
+					}
+				}
+			}
+
+			$objView->AddDef('filter', 'module_id', $module);
+		}
+
+		if (count($product) > 0)
+			$objView->AddDef('filter', 'product', $product);
+
+		if (count($status) > 0)
+		{
+			// Have statuses?  If so, only set status IDs for their associated types instead of the status type ID
+			// then unset the status type id from the array
+			reset($status);
+			$statuses = array();
+			while (list(, $encoded_status) = each($status))
+			{
+				list($type_id, $status_id) = explode(',', $encoded_status);
+				$statuses[count($statuses)] = $status_id;
+				if (count($dcl_status_type) > 0 && in_array($type_id, $dcl_status_type))
+				{
+					reset($dcl_status_type);
+					while(list($key, $status_type_id) = each($dcl_status_type))
+					{
+						if ($status_type_id == $type_id)
+						{
+							unset($dcl_status_type[$key]);
+							break;
+						}
+					}
+				}
+			}
+
+			$objView->AddDef('filter', 'status', $statuses);
+		}
+
+		if (count($account) > 0)
+			$objView->AddDef('filter', 'dcl_wo_account.account_id', $account);
+
+		if (count($dcl_status_type) > 0)
+			$objView->AddDef('filter', 'statuses.dcl_status_type', $dcl_status_type);
+
+		if (count($project) > 0)
+			$objView->AddDef('filter', 'dcl_projects.projectid', $project);
+
 		if ($dateFrom != '' || $dateTo != '')
 		{
 			$fieldList = array('createdon', 'closedon', 'statuson', 'lastactionon', 'deadlineon',
@@ -351,26 +557,41 @@ class boWorkorders
 
 		if (count($columns) > 0)
 			$objView->AddDef('columns', '', $columns);
-		else
-			$objView->AddDef('columns', '', 
-				array('ticketid', 'responsible', 'product', 'account', 'status', 'contact', 'contactphone'));
 
 		if (count($groups) > 0)
+		{
+			reset($groups);
+			while (list($key, $groupField) = each($groups))
+			{
+				if ($groupField == 'priorities.name')
+					$groups[$key] = 'priorities.weight';
+				else if ($groupField == 'severities.name')
+					$groups[$key] = 'severities.weight';
+			}
+
 			$objView->AddDef('groups', '', $groups);
+		}
 
 		if (count($columnhdrs) > 0)
 			$objView->AddDef('columnhdrs', '', $columnhdrs);
 
 		if (count($order) > 0)
+		{
+			reset($order);
+			while (list($key, $orderField) = each($order))
+			{
+				if ($orderField == 'priorities.name')
+					$order[$key] = 'priorities.weight';
+				else if ($orderField == 'severities.name')
+					$order[$key] = 'severities.weight';
+			}
+
 			$objView->AddDef('order', '', $order);
+		}
 		else
 			$objView->AddDef('order', '', array('jcn', 'seq'));
 
-
-		if (count($groups) > 0)
-			$objView->style = 'report';
-		else
-			$objView->style = $GLOBALS['style'];
+		$objView->style = 'report';
 
 		if ($GLOBALS['title'] != '')
 		{
@@ -379,8 +600,8 @@ class boWorkorders
 		}
 		else
 			$objView->title = STR_WO_RESULTSTITLE;
-
-		$obj = CreateObject('dcl.htmlView');
+		
+		$obj = CreateObject('dcl.htmlWorkOrderResults');
 		$obj->Render($objView);
 	}
 
@@ -419,12 +640,16 @@ class boWorkorders
 		$obj->Connect();
 		$beginDate = new DCLTimestamp;
 		$endDate = new DCLTimestamp;
-		$testDate = new DCLTimestamp;
+		$testDate = new DCLDate;
+		$testTS = new DCLTimestamp;
 
 		$endDate->SetFromDisplay($GLOBALS['dateFrom'] . ' 23:59:59');
 		$beginDate->SetFromDisplay($GLOBALS['dateFrom'] . ' 00:00:00');
 		$beginDate->time -= (($GLOBALS["days"] - 1) * 86400);
 		$query = 'SELECT createdon,closedon FROM workorders WHERE ';
+		if ($GLOBALS['product'] > 0)
+			$query .= 'product = ' . $GLOBALS['product'] . 'AND ';
+
 		$query .= '(createdon between ' . $obj->DisplayToSQL($beginDate->ToDisplay());
 		$query .= ' AND ' . $obj->DisplayToSQL($endDate->ToDisplay());
 		$query .= ') OR (closedon between ' . $obj->DisplayToSQL($beginDate->ToDisplay());
@@ -449,13 +674,24 @@ class boWorkorders
 
 		while ($obj->next_record())
 		{
+			$iTime = 0;
 			for ($y = 0; $y < 2; $y++)
 			{
-				$testDate->SetFromDB($obj->f($y));
+				if ($y == 0)
+				{
+					$testTS->SetFromDB($obj->f($y));
+					$iTime = $testTS->time;
+				}
+				else
+				{
+					$testDate->SetFromDB($obj->f($y));
+					$iTime = $testDate->time;
+				}
+
 				$j = $GLOBALS['days'] - 1;
 				while ($j >= 0)
 				{
-					if ($testDate->time >= $daysBack[$j])
+					if ($iTime >= $daysBack[$j])
 					{
 						if (!IsSet($objG->data[$y][$j]))
 							$objG->data[$y][$j] = 0;
@@ -469,6 +705,14 @@ class boWorkorders
 		}
 
 		$objG->title = STR_BO_WOGRAPHTITLE;
+		if (isset($GLOBALS['product']) && $GLOBALS['product'] > 0)
+		{
+			$oDB = CreateObject('dcl.dbProducts');
+			$oDB->Connect();
+			if ($oDB->Load($GLOBALS['product']) != -1)
+				$objG->title .= ' ' . $oDB->name;
+		}
+
 		$objG->caption_y = STR_BO_WOGRAPHCAPTIONY;
 		$objG->caption_x = STR_BO_GRAPHCAPTIONX;
 		$objG->num_lines_y = 15;
@@ -569,6 +813,7 @@ class boWorkorders
 
 		if (IsSet($GLOBALS['selected']) && is_array($GLOBALS['selected']) && count($GLOBALS['selected']) > 0)
 		{
+			$objWtch = CreateObject('dcl.boWatches');
 			$objWO = CreateObject('dcl.dbWorkorders');
 			$objWO->Connect();
 			$bNeedBreak = false;
@@ -586,8 +831,8 @@ class boWorkorders
 					$objWO->priority = $GLOBALS['priority'];
 					$objWO->severity = $GLOBALS['severity'];
 					$objWO->Edit();
-					if ($objWO->responsible != $GLOBALS['DCLID'])
-						$this->SendNewMailMsg($objWO);
+
+					$objWtch->sendNotification($objWO, '4,1');
 				}
 			}
 		}
@@ -597,7 +842,7 @@ class boWorkorders
 
 		$objView = CreateObject('dcl.boView');
 		$objView->SetFromURL();
-		$objH = CreateObject('dcl.htmlView');
+		$objH = CreateObject('dcl.htmlWorkOrderResults');
 		$objH->Render($objView);
 	}
 
@@ -638,8 +883,8 @@ class boWorkorders
 			$o->iType = ATTACHMENT_WORKORDER;
 			$o->iKey1 = $GLOBALS['jcn'];
 			$o->iKey2 = $GLOBALS['seq'];
-			$o->sFileName = $GLOBALS['userfile_name'];
-			$o->sTempFileName = $GLOBALS['userfile'];
+			$o->sFileName = is_array($GLOBALS['userfile']) ? $GLOBALS['userfile']['name'] : $GLOBALS['userfile_name'];
+			$o->sTempFileName = is_array($GLOBALS['userfile']) ? $GLOBALS['userfile']['tmp_name'] : $GLOBALS['userfile'];
 			$o->sRoot = $dcl_info['DCL_FILE_PATH'] . '/attachments';
 			$o->Upload();
 		}
@@ -697,56 +942,46 @@ class boWorkorders
 		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_WO']))
 			return PrintPermissionDenied();
 
-
-		if (($HTTP_POST_VARS['userfile'] == $GLOBALS['userfile']) or ($HTTP_GET_VARS['userfile'] == $GLOBALS['userfile']) or ($HTTP_COOKIE_VARS['userfile'] == $GLOBALS['userfile']))
-		   	{
+		if (IsSet($GLOBALS['userfile']))
+		{
+			if ((IsSet($HTTP_POST_VARS['userfile']) && $HTTP_POST_VARS['userfile'] == $GLOBALS['userfile']) ||
+				(IsSet($HTTP_GET_VARS['userfile']) && $HTTP_GET_VARS['userfile'] == $GLOBALS['userfile']) ||
+				(IsSet($HTTP_COOKIE_VARS['userfile']) && $HTTP_COOKIE_VARS['userfile'] == $GLOBALS['userfile']))
+			{
 				return PrintPermissionDenied();
 			}
+		}
 
-		BeginChocoFont();
-		print('<center>');
-
-		if ($GLOBALS['userfile'] == 'none')
+		$sTempFileName = is_array($GLOBALS['userfile']) ? $GLOBALS['userfile']['tmp_name'] : $GLOBALS['userfile'];
+		if ($sTempFileName == 'none')
 		{
 			echo '<b>' . STR_BO_CSVUPLOADNONE . '</b>';
 			return;
 		}
 
-           // Open the file as text - let PHP take care of line
-           // delimiter differences
-		$ifile = fopen($GLOBALS['userfile'], 'r');
-		if(!ifile) {
+		// Open the file as text - let PHP take care of line
+		// delimiter differences
+		$hFile = fopen($sTempFileName, 'r');
+		if(!$hFile)
+		{
 			echo '<b>' . STR_BO_CSVUPLOADERR . '</b>';
 			return;
 		}
 
-		/////////////////////////////////////////////////////////
-		// Start display file contents
-		print(STR_BO_FILECONTENTS);
-		print(': <p><table border=1>');
-		while($fields = fgetcsv($ifile, 1000)) {
-			print('<tr>');
-			while (list (, $val) = each ($fields))
-				echo '<td>$val</td>';
-			print('</tr>');
-		}
-		print('</table><p><p>');
-		rewind($ifile);
-		// End display file contents
-		////////////////////////////////////////////////////////
-
-           // Get the line containing field names
-		$fields = fgetcsv($ifile, 1000);
-
-           // Now process the file line by line
+		// Get the line containing field names
 		$line = 1;
+		$fields = fgetcsv($hFile, 1000);
 
-           // Define a useful function for mapping a short name to ID
-           // It is really ineffective to instantiate a new object for
-           // each field!
-		function findID($obj, $table, $value, $pk = 'id', $fd = 'short')
+		// Define a useful function for mapping a short name to ID
+		// It is really ineffective to instantiate a new object for
+		// each field!
+		function findID($obj, $table, $value, $pk = 'id', $fd = 'short', $fd2 = '', $val2 = '')
 		{
-			$obj->Query('SELECT ' . $pk . ' FROM ' . $table . ' WHERE ' . $fd . ' = \'' . $value . '\'');
+			$sSQL = "SELECT $pk FROM $table WHERE $fd = '$value'";
+			if ($fd2 != '' && $val2 != '')
+				$sSQL .= " AND $fd2 = $val2";
+
+			$obj->Query($sSQL);
 			if($obj->next_record())
 				return $obj->f(0);
 			else
@@ -759,26 +994,35 @@ class boWorkorders
 		$objTemp->Connect();
 		$objProjectmap = CreateObject('dcl.dbProjectmap');
 		$objProjectmap->Connect();
+		$objWtch = CreateObject('dcl.boWatches');
 
-		while($data = fgetcsv($ifile, 1000)) {
+		while($data = fgetcsv($hFile, 1000))
+		{
 			$line++;
 			$projectid = -1;
+			$module_id = -1;
 			$objWorkorder->Clear();
 
-               // Step through each field in the line
-			while(list($i, $val) = each($data))
+			while (list($i, $val) = each($data))
 			{
-				if(!is_numeric($val))
+				if (!is_numeric($val))
 				{
 					// we may need to convert smth
-					switch($fields[$i])
+					switch ($fields[$i])
 					{
 						case 'product':
 							$new_val = findID($objTemp, 'products', $val);
 							break;
+						case 'module_id':
+							$module_id = $val;
+							continue;
+							break;
 						case 'account':
 							$new_val = findID($objTemp, 'accounts', $val);
 							break;
+						case 'wo_type_id':
+							$new_val = findID($objTemp, 'dcl_wo_type', $val, 'wo_type_id', 'type_name');
+							break;
 						case 'priority':
 							$new_val = findID($objTemp, 'priorities', $val);
 							break;
@@ -794,7 +1038,8 @@ class boWorkorders
 						default:
 							$new_val = $val;
 					}
-					if($new_val == -1)
+
+					if ($new_val == -1)
 					{
 						// An error on mapping
 						echo '<b>';
@@ -802,21 +1047,38 @@ class boWorkorders
 						echo '</b><br>';
 						continue 2;       // On to next line in the file
 					}
+
 					$val = $new_val;
 				}
+				else if ($fields[$i] == 'module_id')
+					$module_id = $val;
 
-				if ($fields[$i] != 'project')
+				if ($fields[$i] != 'project' && $fields[$i] != 'module_id')
 				{
-                    // This will ignore nonexisting members
-   	                // Only works in PHP4 because Clear() initializes each field!
-					if(isset($objWorkorder->$fields[$i]))
-						$objWorkorder->$fields[$i] = addslashes($val);
+					// This will ignore nonexisting members
+					// Only works in PHP4 because Clear() initializes each field!
+					if (isset($objWorkorder->$fields[$i]))
+						$objWorkorder->$fields[$i] = $val;
 				}
 			}
 
+			// Lookup module if specified
+			if ($module_id != -1)
+			{
+				if (is_numeric($module_id))
+				{
+					// just verify this module exists for this product
+					if ($objTemp->ExecuteScalar("SELECT COUNT(*) FROM dcl_product_module WHERE product_module_id = $module_id AND product_id = " . $objWorkorder->product) > 0)
+						$objWorkorder->module_id = $module_id;
+				}
+				else
+					$objWorkorder->module_id = findID($objTemp, 'dcl_product_module', $module_id, 'product_module_id', 'module_name', 'product_id', $objWorkorder->product);
+			}
+
 			$objWorkorder->createby = $GLOBALS['DCLID'];
 			$objWorkorder->Add();
-			if($objWorkorder->jcn)
+
+			if ($objWorkorder->jcn > 0)
 			{
 				if ($projectid > 0)
 				{
@@ -827,17 +1089,15 @@ class boWorkorders
 					$objProjectmap->Add();
 				}
 
+				// Add it to our new work order collection
 				$newjcns[] = $objWorkorder->jcn;
+
+				// Send notification
+				$objWtch->sendNotification($objWorkorder, '4,1');
 			}
-			if ($objWorkorder->responsible != $GLOBALS['DCLID'])
-				$this->SendNewMailMsg($objWorkorder);
 		}
 
-		echo '<p><p>';
-		printf(STR_BO_CSVNEWWOADDED, count($newjcns));
-		echo '<p>';
-
-		// Modified for use with new view object
+		// Display imported work orders
 		$objView = CreateObject('dcl.boView');
 		$objView->style = 'report';
 		$objView->title = 'Work Order CSV Upload Results';
@@ -852,69 +1112,10 @@ class boWorkorders
 			array(STR_WO_JCN, STR_WO_SEQ, STR_WO_RESPONSIBLE, STR_WO_PRODUCT,
 				STR_WO_STATUS, STR_WO_ESTSTART, STR_WO_DEADLINE, STR_WO_ETCHOURS, STR_WO_ACTHOURS, STR_WO_SUMMARY));
 
-		$objHV = CreateObject('dcl.htmlView');
+		$objHV = CreateObject('dcl.htmlWorkOrderResults');
 		$objHV->Render($objView);
 	}
 
-	function SendNewMailMsg($obj)
-	{
-		global $dcl_info;
-
-		if ($dcl_info['DCL_SMTP_ENABLED'] != 'Y' || !is_object($obj))
-			return;
-
-		$objPersonnel = CreateObject('dcl.dbPersonnel');
-		$objPersonnel->Connect($this->conn);
-		$objPersonnel2 = CreateObject('dcl.dbPersonnel');
-		$objPersonnel2->Connect($this->conn);
-
-		$mailFrom = '';
-		if ($objPersonnel->Load($GLOBALS['DCLID']) != -1)
-			$mailFrom = 'From: ' . $objPersonnel->firstNameLast . ' <' . $objPersonnel->email . '>';
-
-		if ($objPersonnel->Load($obj->responsible) == -1)
-			return;
-
-		if ($objPersonnel2->Load($obj->createby) == -1)
-			return;
-
-		if ($objPersonnel->email == '')
-			return;
-
-		$mailMsg = STR_BO_MAILMSG . phpCrLf . phpCrLf;
-		$mailMsg .= sprintf('%s: %d-%d', STR_WO_JCN, $obj->jcn, $obj->seq) . phpCrLf;
-		$mailMsg .= STR_WO_OPENBY . ': ' . $objPersonnel2->lastNameFirst . phpCrLf;
-
-		$objProduct = CreateObject('dcl.dbProducts');
-		$objProduct->Connect($obj->conn);
-		$objProduct->Load($obj->product);
-		$mailMsg .= STR_WO_PRODUCT . ': ' . $objProduct->name . phpCrLf;
-
-		if ($this->account > 0)
-		{
-			$objAccount = CreateObject('dcl.dbAccounts');
-			$objAccount->Connect($obj->conn);
-			$objAccount->Load($obj->account);
-			$mailMsg .= STR_WO_ACCOUNT . ': ' . $objAccount->name . phpCrLf;
-		}
-
-		$mailMsg .= STR_WO_SUMMARY . ': ' . $obj->summary . phpCrLf . phpCrLf;
-		$mailMsg .= sprintf(STR_BO_SEEDETAILAT,
-				$dcl_info['DCL_ROOT'] . 'main.php?menuAction=boWorkorders.viewjcn&jcn=' . $obj->jcn . '&seq=' . $obj->seq . '&domain=' . $GLOBALS['dcl_domain']);
-		$mailMsg .= phpCrLf . phpCrLf . STR_WO_EMAILSIG;
-
-		$oMail = CreateObject('dcl.boSMTP');
-		$oMail->to = $objPersonnel->email;
-		$oMail->from = $GLOBALS['USEREMAIL'];
-		$oMail->subject = sprintf(STR_WO_EMAILSUBJECT, $obj->jcn, $obj->seq);
-		$oMail->body = $mailMsg;
-		$oMail->Send();
-
-		print('<P><CENTER>');
-		PrintWithChocoFont(sprintf(STR_BO_MAILSENT, $objPersonnel->email));
-		print('</CENTER><P>');
-	}
-
 	function showmy()
 	{
 		commonHeader();
@@ -951,7 +1152,7 @@ class boWorkorders
 		{
 			$objView = CreateObject('dcl.boView');
 			$objView->SetFromURL();
-			$objH = CreateObject('dcl.htmlView');
+			$objH = CreateObject('dcl.htmlWorkOrderResults');
 			$objH->Render($objView);
 		}
 	}
