@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: class.htmlConfig.inc.php,v 1.3.2.3.2.1 2002/10/24 04:58:10 mdean Exp $
+ * $Id: class.htmlConfig.inc.php,v 1.3.2.3.2.9 2003/12/28 19:41:15 mdean Exp $
  *
  * Double Choco Latte - Source Configuration Management System
  * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
@@ -45,6 +45,8 @@ class htmlConfig
 
 		$Template->set_var('TXT_CONFIGTITLE', STR_CFG_TITLE);
 		$Template->set_var('TXT_CONFIGDESC', STR_CFG_DESC);
+		$Template->set_var('VAL_SYSTEMSETUPHREF', menuLink('', 'menuAction=boAdmin.ShowSystemConfig'));
+		$Template->set_var('TXT_SYSTEMSETUP', DCL_MENU_SYSTEMSETUP);
 
 		// System
 		$Template->set_var('TXT_SYSTEMTITLE', STR_CFG_SYSTEMTITLE);
@@ -59,6 +61,7 @@ class htmlConfig
 		$Template->set_var('TXT_FILEPATH', STR_CFG_FILEPATH);
 		$Template->set_var('TXT_ROOT', STR_CFG_ROOT);
 		$Template->set_var('TXT_GDTYPE', STR_CFG_GDTYPE);
+		$Template->set_var('TXT_SESSIONTIMEOUT', STR_CFG_SESSIONTIMEOUT);
 
 		$Template->set_var('CMB_DATEFORMAT', $this->GetDateCombo('DCL_DATE_FORMAT', $dcl_info['DCL_DATE_FORMAT']));
 		$Template->set_var('CMB_DATEFORMATDB', $this->GetDateCombo('DCL_DATE_FORMAT_DB', $dcl_info['DCL_DATE_FORMAT_DB']));
@@ -71,6 +74,7 @@ class htmlConfig
 		$Template->set_var('VAL_FILEPATH', $dcl_info['DCL_FILE_PATH']);
 		$Template->set_var('VAL_ROOT', $dcl_info['DCL_ROOT']);
 		$Template->set_var('CMB_GDTYPE', $this->GetGraphicsCombo('DCL_GD_TYPE', $dcl_info['DCL_GD_TYPE']));
+		$Template->set_var('VAL_SESSIONTIMEOUT', $dcl_info['DCL_SESSION_TIMEOUT']);
 
 		// SMTP Server Settings
 		$Template->set_var('TXT_EMAILSERVERTITLE', STR_CFG_EMAILSERVERTITLE);
@@ -122,6 +126,7 @@ class htmlConfig
 		$Template->set_var('TXT_TIMECARDORDER', STR_CFG_TIMECARDORDER);
 		$Template->set_var('TXT_WONOTIFICATIONHTML', 'Send Work Order Notifications as HTML*');
 		$Template->set_var('TXT_WOEMAILTEMPLATE', 'Work Order Notification Template (templates/custom dir)*');
+		$Template->set_var('TXT_WOSECONDARYACCOUNTSENABLED', 'Allow Mutiple Accounts Per Work Order (Not Compatible With MySQL)');
 
 		$Template->set_var('CMB_DEFAULTSTATUSASSIGN', $this->GetStatusCombo('DCL_DEF_STATUS_ASSIGN_WO', $dcl_info['DCL_DEF_STATUS_ASSIGN_WO']));
 		$Template->set_var('CMB_DEFAULTSTATUSUNASSIGN', $this->GetStatusCombo('DCL_DEF_STATUS_UNASSIGN_WO', $dcl_info['DCL_DEF_STATUS_UNASSIGN_WO']));
@@ -131,6 +136,7 @@ class htmlConfig
 		$Template->set_var('CMB_TIMECARDORDER', $this->GetDisplayOrderCombo('DCL_TIME_CARD_ORDER', $dcl_info['DCL_TIME_CARD_ORDER']));
 		$Template->set_var('VAL_WONOTIFICATIONHTML', $dcl_info['DCL_WO_NOTIFICATION_HTML'] == 'Y' ? ' checked' : '');
 		$Template->set_var('VAL_WOEMAILTEMPLATE', $dcl_info['DCL_WO_EMAIL_TEMPLATE']);
+		$Template->set_var('VAL_WOSECONDARYACCOUNTSENABLED', $dcl_info['DCL_WO_SECONDARY_ACCOUNTS_ENABLED'] == 'Y' ? ' checked' : '');
 
 		// Projects
 		$Template->set_var('TXT_PROJECTTITLE', STR_CFG_PROJECTTITLE);
@@ -164,6 +170,16 @@ class htmlConfig
 		$Template->set_var('VAL_TCKNOTIFICATIONHTML', $dcl_info['DCL_TCK_NOTIFICATION_HTML'] == 'Y' ? ' checked' : '');
 		$Template->set_var('VAL_TCKEMAILTEMPLATE', $dcl_info['DCL_TCK_EMAIL_TEMPLATE']);
 
+		// Wiki
+		$Template->set_var('TXT_WIKI', STR_CFG_WIKI);
+		$Template->set_var('TXT_WIKIENABLED', STR_CFG_WIKIENABLED);
+		$Template->set_var('TXT_WIKIVIEWLEVEL', STR_CFG_WIKIVIEWLEVEL);
+		$Template->set_var('TXT_WIKIEDITLEVEL', STR_CFG_WIKIEDITLEVEL);
+
+		$Template->set_var('VAL_WIKIENABLED', $dcl_info['DCL_WIKI_ENABLED'] == 'Y' ? ' checked' : '');
+		$Template->set_var('CMB_WIKIVIEW', $this->GetSecurityCombo('DCL_WIKI_VIEW', $dcl_info['DCL_WIKI_VIEW']));
+		$Template->set_var('CMB_WIKIEDIT', $this->GetSecurityCombo('DCL_WIKI_EDIT', $dcl_info['DCL_WIKI_EDIT']));
+
 		// e-Mail Gateway for Tickets
 		$Template->set_var('TXT_GATEWAYTICKETTITLE', STR_CFG_GATEWAYTICKETTITLE);
 		$Template->set_var('TXT_GATEWAYTICKETENABLED', STR_CFG_GATEWAYTICKETENABLED);
@@ -188,6 +204,32 @@ class htmlConfig
 		$Template->set_var('CMB_GATEWAYTICKETREPLYLOGGEDBY', $this->GetPersonnelCombo('DCL_GATEWAY_TICKET_REPLY_LOGGED_BY', $dcl_info['DCL_GATEWAY_TICKET_REPLY_LOGGED_BY']));
 		$Template->set_var('VAL_GATEWAYTICKETFILEPATH', $dcl_info['DCL_GATEWAY_TICKET_FILE_PATH']);
 
+		// e-Mail Gateway for Work Orders
+		$Template->set_var('TXT_GATEWAYWOTITLE', STR_CFG_GATEWAYWOTITLE);
+		$Template->set_var('TXT_GATEWAYWOENABLED', STR_CFG_GATEWAYWOENABLED);
+		$Template->set_var('TXT_GATEWAYWOAUTORESPOND', STR_CFG_GATEWAYWOAUTORESPOND);
+		$Template->set_var('TXT_GATEWAYWOAUTORESPONSEEMAIL', STR_CFG_GATEWAYWOAUTORESPONSEEMAIL);
+		$Template->set_var('TXT_GATEWAYWOREPLY', STR_CFG_GATEWAYWOREPLY);
+		$Template->set_var('TXT_GATEWAYWOSTATUS', STR_CFG_GATEWAYWOSTATUS);
+		$Template->set_var('TXT_GATEWAYWOPRIORITY', STR_CFG_GATEWAYWOPRIORITY);
+		$Template->set_var('TXT_GATEWAYWOSEVERITY', STR_CFG_GATEWAYWOSEVERITY);
+		$Template->set_var('TXT_GATEWAYWOFILEPATH', STR_CFG_GATEWAYWOFILEPATH);
+
+		$Template->set_var('VAL_GATEWAYWOENABLED', $dcl_info['DCL_GATEWAY_WO_ENABLED'] == 'Y' ? ' checked' : '');
+		$Template->set_var('VAL_GATEWAYWOAUTORESPOND', $dcl_info['DCL_GATEWAY_WO_AUTORESPOND'] == 'Y' ? ' checked' : '');
+		$Template->set_var('VAL_GATEWAYWOAUTORESPONSEEMAIL', $dcl_info['DCL_GATEWAY_WO_AUTORESPONSE_EMAIL']);
+		$Template->set_var('VAL_GATEWAYWOREPLY', $dcl_info['DCL_GATEWAY_WO_REPLY'] == 'Y' ? ' checked' : '');
+		$Template->set_var('CMB_GATEWAYWOSTATUS', $this->GetStatusCombo('DCL_GATEWAY_WO_STATUS', $dcl_info['DCL_GATEWAY_WO_STATUS']));
+		$Template->set_var('CMB_GATEWAYWOPRIORITY', $this->GetPriorityCombo('DCL_GATEWAY_WO_PRIORITY', $dcl_info['DCL_GATEWAY_WO_PRIORITY']));
+		$Template->set_var('CMB_GATEWAYWOSEVERITY', $this->GetSeverityCombo('DCL_GATEWAY_WO_SEVERITY', $dcl_info['DCL_GATEWAY_WO_SEVERITY']));
+		$Template->set_var('VAL_GATEWAYWOFILEPATH', $dcl_info['DCL_GATEWAY_WO_FILE_PATH']);
+
+		// SCCS Integration
+		$Template->set_var('TXT_SCCS', 'SCCS Integration');
+		$Template->set_var('TXT_SCCSENABLED', 'SCCS Integration Enabled');
+
+		$Template->set_var('VAL_SCCSENABLED', $dcl_info['DCL_SCCS_ENABLED'] == 'Y' ? ' checked' : '');
+
 		$Template->pparse('out', 'hForm');
 	}
 
@@ -256,6 +298,7 @@ class htmlConfig
 				'fr' => 'French',
 				'de' => 'German',
 				'it' => 'Italian',
+				'ru' => 'Russian',
 				'es' => 'Spanish',
 				'sl' => 'Slovenina',
 				'sv' => 'Swedish'
@@ -279,11 +322,16 @@ class htmlConfig
 	{
 		$aOptions = array();
 		$sPath = './templates/';
-		if ($hDir = @opendir($sPath))
-			while ($fileName = @readdir($hDir))
+		if (is_dir($sPath) && $hDir = opendir($sPath))
+		{
+			while ($fileName = readdir($hDir))
 				if (is_dir($sPath . $fileName) && $fileName != '.' && $fileName != '..' && $fileName != 'CVS' && $fileName != 'custom')
 					$aOptions[$fileName] = $fileName;
 
+			if ($hDir)
+				closedir($hDir);
+		}
+
 		return $this->_GetCombo($sName, $aOptions, $sDefault);
 	}
 
