@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: class.htmlProjectsdetail.inc.php,v 1.5.4.8 2003/01/26 18:29:15 mdean Exp $
+ * $Id: class.htmlProjectsdetail.inc.php,v 1.5.4.15 2003/10/19 21:24:16 mdean Exp $
  *
  * Double Choco Latte - Source Configuration Management System
  * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
@@ -47,17 +47,23 @@ class htmlProjectsdetail
 
 		if ($GLOBALS['SEC'] >= $dcl_info['DCL_ASSIGN_WO'])
 		{
-			$options['boWorkorders.batchdetail'] = 'Batch Detail*';
-			$options['boTimecards.batchadd'] = 'Batch Timecard*';
-			$options['boWorkorders.batchassign'] = 'Batch Assign*';
-			$options['htmlProjectmap.batchMove'] = 'Batch Move*';
+			$options['boWorkorders.batchdetail'] = STR_PRJ_BATCHDETAIL;
+			$options['boTimecards.batchadd'] = STR_PRJ_BATCHTIMECARD;
+			$options['boWorkorders.batchassign'] = STR_PRJ_BATCHASSIGN;
+			$options['htmlProjectmap.batchMove'] = STR_PRJ_BATCHMOVE;
 		}
 
 		if (ereg('w', $include))
 			$options['boWatches.add'] = STR_PRJ_ADDWATCH;
 
 		if (ereg('a', $include))
-			$options['boWorkorders.newjcn'] = 'Add Work Order To This Project*';
+			$options['boWorkorders.newjcn'] = STR_PRJ_ADDWOTOTHISPROJECT;
+
+		if ($dcl_info['DCL_SCCS_ENABLED'] == 'Y')
+			$options['htmlProjects.changeLog'] = 'ChangeLog';
+			
+		if ($dcl_info['DCL_WIKI_ENABLED'] == 'Y')
+			$options['htmlWiki.show'] = STR_CMMN_WIKI;
 
 		asort($options);
 		reset($options);
@@ -67,11 +73,11 @@ class htmlProjectsdetail
 		$cmbText .= '</select>' . phpCrLf;
 		return $cmbText;
 	}
-	
+
 	function GetGroupByCombo()
 	{
 		$default = IsSet($GLOBALS['wogroupby']) ? $GLOBALS['wogroupby'] : 'none';
-		$options = array('none' => 'None', '2' => 'Assigned', '6' => 'Status', '3' => 'Product', '4' => 'Module');
+		$options = array('none' => STR_CMMN_SELECTONE, '3' => 'Assigned', '7' => STR_WO_STATUS, '4' => STR_WO_PRODUCT, '5' => STR_CMMN_MODULE, '2' => STR_WO_TYPE);
 		
 		$retVal = '<select name="wogroupby">';
 		while (list($k, $v) = each($options))
@@ -119,6 +125,8 @@ class htmlProjectsdetail
 		$Template->set_block('hWO', 'workorders', 'hWorkorders');
 		$Template->set_block('hWO', 'nogrouping', 'hNoGrouping');
 		$Template->set_block('hWO', 'grouping', 'hGrouping');
+		$Template->set_block('workorders', 'secaccounts', 'hSecaccounts');
+		$Template->set_block('parent', 'parentpath', 'hParentpath');
 
 		$Template->set_var('hAttachments', '');
 		$Template->set_var('hParent', '');
@@ -126,6 +134,8 @@ class htmlProjectsdetail
 		$Template->set_var('hWorkorders', '');
 		$Template->set_var('hNoGrouping', '');
 		$Template->set_var('hGrouping', '');
+		$Template->set_var('hSecaccounts', '');
+		$Template->set_var('hParentpath', '');
 
 		$Template->set_var('COLOR_DARK', $dcl_info['DCL_COLOR_DARK']);
 		$Template->set_var('COLOR_LIGHT', $dcl_info['DCL_COLOR_LIGHT']);
@@ -164,6 +174,7 @@ class htmlProjectsdetail
 		$Template->set_var('VAL_LASTACTIVITY', $objDBProjects->lastactivity);
 		$Template->set_var('VAL_FINALCLOSE', htmlspecialchars($objDBProjects->finalclose));
 		$Template->set_var('VAL_DESCRIPTION', nl2br(htmlspecialchars($objDBProjects->description)));
+		$Template->set_var('VAL_WIKITYPE', 1); // 1 = DCL_WIKI_PROJECT
 		$Template->set_var('CMB_ACTION', $this->GetActionCombo('exfwa'));
 
 		$objPersonnel = CreateObject('dcl.dbPersonnel');
@@ -171,7 +182,7 @@ class htmlProjectsdetail
 		$objPersonnel->Load($objDBProjects->reportto);
 		$Template->set_var('VAL_REPORTTO', $objPersonnel->short);
 
-		$arrayStats = $objDBProjects->GetProjectStatistics($projectid, $dcl_info['DCL_PROJECT_INCLUDE_CHILD_STATS'], $dcl_info['DCL_PROJECT_INCLUDE_PARENT_STATS']);
+		$arrayStats = $objDBProjects->GetProjectStatistics($projectid, $dcl_info['DCL_PROJECT_INCLUDE_CHILD_STATS'] == 'Y', $dcl_info['DCL_PROJECT_INCLUDE_PARENT_STATS'] == 'Y');
 		$Template->set_var('VAL_TOTALTASKS', $arrayStats['totaltasks']);
 		$Template->set_var('VAL_TASKSCLOSED', $arrayStats['tasksclosed']);
 		$Template->set_var('VAL_ESTHOURS', $arrayStats['esthours']);
@@ -228,8 +239,20 @@ class htmlProjectsdetail
 		else
 			$Template->set_var('VAL_PCTCOMP', '0.00%');
 
-		$objHStat = CreateObject('dcl.htmlStatuses');
-		$Template->set_var('CMB_WOSTATUS', $objHStat->GetCombo($wostatus, 'wostatus'));
+		$objHStat = CreateObject('dcl.htmlSelect');
+		$objHStat->vDefault = $wostatus;
+		$objHStat->sName = 'wostatus';
+		$objHStat->iSize = 0;
+		$objHStat->sZeroOption = STR_CMMN_SELECTONE;
+
+		$oStatus = CreateObject('dcl.dbStatuses');
+		$oStatus->Connect();
+		$oStatus->Query('SELECT id, name FROM statuses ORDER BY name');
+		$objHStat->aOptions = $oStatus->FetchAllRows();
+		$i = count($objHStat->aOptions);
+		$objHStat->aOptions[$i++] = array('-1', STR_CMMN_HIDECLOSEDTYPES);
+		$objHStat->aOptions[$i++] = array('-2', STR_CMMN_ONLYCLOSEDTYPES);
+		$Template->set_var('CMB_WOSTATUS', $objHStat->GetHTML());
 
 		$objHPersonnel = CreateObject('dcl.htmlPersonnel');
 		$Template->set_var('CMB_WORESPONSIBLE', $objHPersonnel->GetCombo($woresponsible, 'woresponsible', 'short', 0, false, $dcl_info['DCL_HAVE_WO'], $projectid));
@@ -265,15 +288,27 @@ class htmlProjectsdetail
 			}
 		}
 
+		// Parent Projects
 		$objTemp = CreateObject('dcl.dbProjects');
 		$objTemp->Connect($objDBProjects->conn);
+
 		if ($objDBProjects->parentprojectid > 0)
 		{
-			$objTemp->Load($objDBProjects->parentprojectid);
+			$project_path = array_reverse(explode(',', $objTemp->GetProjectParents($objDBProjects->parentprojectid, true)));
+			$project_link = '';
+
+			while (list($key, $project_id) = each($project_path))
+			{
+				$objTemp->Load($project_id);
+				$Template->set_var('VAL_PARENTNAME', htmlspecialchars($objTemp->name));
+				$Template->set_var('VAL_PARENTLINK',
+					menuLink('', sprintf('menuAction=boProjects.viewproject&project=%d&wostatus=0', $objTemp->projectid)));
+
+				$Template->parse('hParentpath', 'parentpath', true);
+			}
+
 			$Template->set_var('TXT_PARENTPRJ', STR_PRJ_PARENTPRJ);
-			$Template->set_var('VAL_PARENTID', $objTemp->projectid);
-			$Template->set_var('VAL_PARENTNAME', htmlspecialchars($objTemp->name));
-			$Template->set_var('VAL_PARENTLINK', menuLink('', sprintf('menuAction=boProjects.viewproject&project=%d&wostatus=0', $objTemp->projectid)));
+			$Template->set_var('VAL_PARENTID', $objDBProjects->parentprojectid);
 			$Template->parse('hParent', 'parent');
 		}
 
@@ -316,23 +351,41 @@ class htmlProjectsdetail
 		if ($dcl_domain_info[$dcl_domain]['dbType'] == 'mysql') // Hackage to make MySQL happy again
 			$joinKeyword = ' INNER';
 
-		$cols = array('a.jcn', 'a.seq', 'b.short', 'c.name', 'g.module_name', 'd.name', 'e.name', 'a.deadlineon', 'a.totalhours', 'a.etchours', 'a.esthours', '(a.totalhours + a.etchours) - a.esthours', 'a.summary');
-		$sql = 'Select a.jcn, a.seq, b.short, c.name, g.module_name, d.name, e.name, a.deadlineon, a.totalhours, a.etchours, a.esthours, (a.totalhours + a.etchours) - a.esthours, a.summary';
+		$cols = array('a.jcn', 'a.seq', 'h.type_name', 'b.short', 'c.name', 'g.module_name', 'd.name', 'e.name', 'a.deadlineon', 'a.totalhours', 'a.etchours', 'a.esthours', '(a.totalhours + a.etchours) - a.esthours', 'a.summary');
+		$sql = 'Select a.jcn, a.seq, h.type_name, b.short, c.name, g.module_name, d.name, e.name, a.deadlineon, a.totalhours, a.etchours, a.esthours, (a.totalhours + a.etchours) - a.esthours, a.summary';
+
+		if ($dcl_info['DCL_WO_SECONDARY_ACCOUNTS_ENABLED'] == 'Y')
+		{
+			$sql .= ', (select count(*) from dcl_wo_account where wo_id = a.jcn And seq = a.seq) As num_accounts';
+		}
+
 		$sql .= ' From workorders a';
 		$sql .= $joinKeyword . ' JOIN personnel b ON a.responsible = b.id';
 		$sql .= $joinKeyword . ' JOIN products c ON a.product = c.id';
-		$sql .= ' LEFT JOIN accounts d ON a.account = d.id';
+		$sql .= ' LEFT JOIN dcl_wo_account i ON a.jcn = i.wo_id AND a.seq = i.seq';
+		$sql .= ' LEFT JOIN accounts d ON i.account_id = d.id';
 		$sql .= $joinKeyword . ' JOIN statuses e ON a.status = e.id';
 		$sql .= $joinKeyword . ' JOIN projectmap f ON a.jcn = f.jcn and f.seq in (0, a.seq)';
 		$sql .= ' LEFT JOIN dcl_product_module g ON a.module_id = g.product_module_id';
+		$sql .= $joinKeyword . ' JOIN dcl_wo_type h ON a.wo_type_id = h.wo_type_id';
 		$sql .= ' Where f.projectid=' . $projectid;
 
 		if ($wostatus > 0)
 			$sql .= ' And a.status=' . $wostatus;
+		else if ($wostatus == -1)
+			$sql .= ' And e.dcl_status_type != 2';
+		else if ($wostatus == -2)
+			$sql .= ' And e.dcl_status_type = 2';
 
 		if ($woresponsible > 0)
 			$sql .= ' And a.responsible=' . $woresponsible;
 
+		if ($dcl_info['DCL_WO_SECONDARY_ACCOUNTS_ENABLED'] == 'Y')
+		{
+			$sql .= ' And (i.account_id is null Or i.account_id = ';
+			$sql .= '(Select min(account_id) From dcl_wo_account where wo_id = a.jcn And seq = a.seq))';
+		}
+
 		if ($bIsGrouping)
 			$sql .= ' Order By ' . $cols[$GLOBALS['wogroupby']] . ', a.jcn, a.seq';
 		else
@@ -347,6 +400,7 @@ class htmlProjectsdetail
 				$Template->set_var('TXT_TITLE', STR_PRJ_TASKLIST);
 				$Template->set_var('TXT_WO', STR_WO_JCN);
 				$Template->set_var('TXT_SEQ', STR_WO_SEQ);
+				$Template->set_var('TXT_TYPE', STR_WO_TYPE);
 				$Template->set_var('TXT_ASN', STR_WO_ASSIGNABB);
 				$Template->set_var('TXT_PRODUCT', STR_WO_PRODUCT);
 				$Template->set_var('TXT_MODULE', 'Module');
@@ -360,16 +414,21 @@ class htmlProjectsdetail
 				$Template->set_var('TXT_PCTCOMPLETE', '% Complete');
 				$Template->set_var('TXT_SUMMARY', STR_WO_SUMMARY);
 				$Template->set_var('TXT_OPTIONS', STR_CMMN_OPTIONS);
+				$Template->set_var('DIR_IMAGES', 'templates/' . GetDefaultTemplateSet() . '/img');
 
 				// If not grouping, put button at top
 				if (!$bIsGrouping)
 					$Template->parse('hNoGrouping', 'nogrouping');
 
 				$objHWO = CreateObject('dcl.htmlWorkorders');
+				$objWOAcct = CreateObject('dcl.dbWorkOrderAccount');
+				$objWOAcct->Connect();
+
 				$oDate = new DCLDate;
 				$lastGroupVal = '___UNDEFINED___';
 				for ($i = 0; $i < count($allRecs); $i++)
 				{
+					$Template->set_var('hSecaccounts', '');
 					$Template->set_var('HDR_GROUP', '');
 					if ($bIsGrouping && $lastGroupVal != $allRecs[$i][$GLOBALS['wogroupby']])
 					{
@@ -382,48 +441,57 @@ class htmlProjectsdetail
 
 					$Template->set_var('VAL_WOID', $allRecs[$i][0]);
 					$Template->set_var('VAL_SEQ', $allRecs[$i][1]);
-					$Template->set_var('VAL_RESPONSIBLE', $allRecs[$i][2]);
-					$Template->set_var('VAL_PRODUCT', $allRecs[$i][3]);
-					$Template->set_var('VAL_MODULE', $allRecs[$i][4]);
-					$Template->set_var('VAL_ACCOUNT', $allRecs[$i][5]);
+					$Template->set_var('VAL_TYPE', $allRecs[$i][2]);
+					$Template->set_var('VAL_RESPONSIBLE', $allRecs[$i][3]);
+					$Template->set_var('VAL_PRODUCT', $allRecs[$i][4]);
+					$Template->set_var('VAL_MODULE', $allRecs[$i][5]);
+					$Template->set_var('VAL_ACCOUNT', $allRecs[$i][6]);
 
-					$Template->set_var('VAL_STATUS', $allRecs[$i][6]);
-					$Template->set_var('VAL_HRS', $allRecs[$i][8]);
-					$Template->set_var('VAL_ETC', $allRecs[$i][9]);
-					$Template->set_var('VAL_PRJ', $allRecs[$i][10]);
-					$Template->set_var('VAL_SUMMARY', $allRecs[$i][12]);
+					$Template->set_var('VAL_STATUS', $allRecs[$i][7]);
+					$Template->set_var('VAL_HRS', $allRecs[$i][9]);
+					$Template->set_var('VAL_ETC', $allRecs[$i][10]);
+					$Template->set_var('VAL_PRJ', $allRecs[$i][11]);
+					$Template->set_var('VAL_SUMMARY', $allRecs[$i][13]);
 
-					$oDate->SetFromDB($allRecs[$i][7]);
+					$oDate->SetFromDB($allRecs[$i][8]);
 					$Template->set_var('VAL_DEADLINE', $oDate->ToDisplay());
 
-					$ouHours = -($allRecs[$i][10] - $allRecs[$i][8]);
+					$ouHours = -($allRecs[$i][11] - $allRecs[$i][9]);
 					$diffHours = $ouHours;
 					if ($diffHours < 0)
 						$diffHours = -$diffHours;
 
 					$ouPct = 0.0;
 					$sign = '';
-					if ($allRecs[$i][10] > 0)
+					if ($allRecs[$i][11] > 0)
 					{
-						$ouPct = $diffHours / $allRecs[$i][10] * 100;
-						if ($allRecs[$i][10] > $allRecs[$i][8] && $allRecs[$i][10] > 0)
+						$ouPct = $diffHours / $allRecs[$i][11] * 100;
+						if ($allRecs[$i][11] > $allRecs[$i][9] && $allRecs[$i][11] > 0)
 							$sign = '-';
-						else if ($allRecs[$i][8] > $allRecs[$i][10] && $allRecs[$i][8] > 0)
+						else if ($allRecs[$i][9] > $allRecs[$i][11] && $allRecs[$i][9] > 0)
 							$sign = '+';
 					}
 
 					$Template->set_var('VAL_PLUSMINUS', sprintf('%s%0.2f&nbsp;(%s%0.2f%%)', $sign, abs($ouHours), $sign, abs($ouPct)));
 
-					if ($allRecs[$i][9] + $allRecs[$i][8] > 0)
-						$allRecs[$i][12] = (($allRecs[$i][8] / ($allRecs[$i][9] + $allRecs[$i][8])) * 100);
-					elseif ($allRecs[$i][9] == 0.0)
-						$allRecs[$i][12] = 100.0;
+					if ($allRecs[$i][10] + $allRecs[$i][9] > 0)
+						$allRecs[$i][13] = (($allRecs[$i][9] / ($allRecs[$i][10] + $allRecs[$i][9])) * 100);
+					elseif ($allRecs[$i][10] == 0.0)
+						$allRecs[$i][13] = 100.0;
 					else
-						$allRecs[$i][12] = 0.0;
+						$allRecs[$i][13] = 0.0;
 
-					$Template->set_var('VAL_PCTCOMPLETE', sprintf("%0.2f%%", $allRecs[$i][12]));
+					$Template->set_var('VAL_PCTCOMPLETE', sprintf("%0.2f%%", $allRecs[$i][13]));
 					$Template->set_var('VAL_OPTIONS', $objHWO->GetActionLinks('dteasxuw', false, $allRecs[$i][0], $allRecs[$i][1], true));
 
+					if ($dcl_info['DCL_WO_SECONDARY_ACCOUNTS_ENABLED'] == 'Y')
+					{
+						if ($allRecs[$i][14] > 1)
+							$Template->parse('hSecaccounts', 'secaccounts');
+						else
+							$Template->set_var('hSecaccounts', '');
+					}
+
 					$Template->parse('hWorkorders', 'workorders', true);
 				}
 
