@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: class.htmlWorkorders.inc.php,v 1.4.2.2.2.3 2002/12/03 01:48:28 mdean Exp $
+ * $Id: class.htmlWorkorders.inc.php,v 1.4.2.2.2.13 2003/12/10 05:54:06 mdean Exp $
  *
  * Double Choco Latte - Source Configuration Management System
  * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
@@ -23,6 +23,7 @@
  */
 
 LoadStringResource('wo');
+LoadStringResource('prj');
 
 class htmlWorkorders
 {
@@ -123,7 +124,7 @@ class htmlWorkorders
 
 	function GetActionCombo($include, $jcn, $seq)
 	{
-		global $dcl_info;
+		global $dcl_info, $g_oSec;
 
 		$cmbText = '<select name="menuAction">';
 		$options = array();
@@ -157,6 +158,12 @@ class htmlWorkorders
 		if (ereg('w', $include))
 			$options['boWatches.add'] = STR_WO_WATCHES;
 
+		if ($dcl_info['DCL_SCCS_ENABLED'] == 'Y')
+			$options['htmlWorkorders.changeLog'] = 'ChangeLog';
+
+		if ($dcl_info['DCL_WIKI_ENABLED'] == 'Y' && $g_oSec->HasSecLvl($dcl_info['DCL_WIKI_VIEW']))
+			$options['htmlWiki.show'] = STR_CMMN_WIKI;
+
 		asort($options);
 		reset($options);
 		while (list($value, $text) = each($options))
@@ -173,7 +180,9 @@ class htmlWorkorders
 		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ASSIGN_WO']))
 			return PrintPermissionDenied();
 
-		$bIsBatch = is_array($GLOBALS['selected']) && count($GLOBALS['selected']) > 1;
+		IncludeCalendar();
+
+		$bIsBatch = IsSet($GLOBALS['selected']) && is_array($GLOBALS['selected']) && count($GLOBALS['selected']) > 0;
 
 		$objWO = CreateObject('dcl.dbWorkorders');
 		$objProduct = CreateObject('dcl.dbProducts');
@@ -226,7 +235,7 @@ class htmlWorkorders
 				
 			$hiddenvars .= GetHiddenVar('menuAction', 'boWorkorders.dbbatchassign');
 
-			$Template->set_var('TXT_TITLE', 'Batch Assign*');
+			$Template->set_var('TXT_TITLE', STR_PRJ_BATCHASSIGN);
 			$Template->set_var('VAL_FORMACTION', menuLink());
 
 			$Template->set_var('CMB_RESPONSIBLE', $objHTMLPersonnel->GetCombo($GLOBALS['DCLID'], 'responsible', 'lastfirst', 0, true, $dcl_info['DCL_HAVE_WO']));
@@ -310,7 +319,7 @@ class htmlWorkorders
 	}
 
        // THANKS: Urmet Janes
-	function ShowCSVUploadDialog() 
+	function ShowCSVUploadDialog()
 	{
 		global $dcl_info;
 
@@ -320,7 +329,7 @@ class htmlWorkorders
 		$Template = CreateTemplate(array('hForm' => 'htmlWorkOrderCSVUpload.tpl'));
 		$Template->set_var('COLOR_DARK', $dcl_info['DCL_COLOR_DARK']);
 		$Template->set_var('COLOR_LIGHT', $dcl_info['DCL_COLOR_LIGHT']);
-		$Template->set_var('TXT_TITLE', STR_WO_CSVTITLE . '&nbsp;' . GetHelpLink());
+		$Template->set_var('TXT_TITLE', STR_WO_CSVTITLE);
 		$Template->set_var('TXT_CSVFILE', STR_WO_CSVFILE);
 		$Template->set_var('VAL_MAXUPLOADFILESIZE', $dcl_info['DCL_MAX_UPLOAD_FILE_SIZE']);
 		$Template->set_var('VAL_FORMACTION', menuLink());
@@ -334,6 +343,8 @@ class htmlWorkorders
 	{
 		global $dcl_info;
 
+		IncludeCalendar();
+
 		$Template = CreateTemplate(array('hForm' => 'htmlTicketGraph.tpl'));
 
 		$Template->set_var('VAL_JSDATEFORMAT', GetJSDateFormat());
@@ -349,9 +360,61 @@ class htmlWorkorders
 		$Template->set_var('VAL_MENUACTION', 'boWorkorders.showgraph');
 		$Template->set_var('BTN_OK', STR_CMMN_GO);
 
+		$o = CreateObject('dcl.htmlProducts');
+		$Template->set_var('CMB_PRODUCTS', $o->GetCombo(0, 'product', 'name', 0, 0, false));
+		$Template->set_var('TXT_PRODUCT', STR_WO_PRODUCT);
+
 		$Template->pparse('out', 'hForm');
 	}
 
+	function changeLog()
+	{
+		global $dcl_info;
+
+		commonHeader();
+
+		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_HAVE_WO']))
+			return PrintPermissionDenied();
+
+		$jcn = intval($GLOBALS['jcn']);
+		$seq = intval($GLOBALS['seq']);
+
+		$o = CreateObject('dcl.dbSccsXref');
+		$o->Connect();
+		if ($o->ListChangeLog(DCL_ENTITY_WORKORDER, $jcn, $seq) != -1)
+		{
+			$allRecs = array();
+			while ($o->next_record())
+			{
+				$allRecs[] = array($o->f(0) . ': ' . $o->f(2), $o->f(1), $o->f(3), $o->f(4), $o->f(5), $o->FormatTimestampForDisplay($o->f(6)));
+			}
+
+			$titleLink = '<a class="adark" href="' . menuLink('', "menuAction=boWorkorders.viewjcn&jcn=$jcn&seq=$seq") . '">' . 'Back' . '</a>';
+
+			if (count($allRecs) > 0)
+			{
+				$allName = array(
+						0 => 'Project',
+						1 => 'Changed By',
+						2 => 'File',
+						3 => 'Version',
+						4 => 'Comments',
+						5 => 'Date');
+
+				PrintArrayAsChocoTable($allName, $allRecs, "ChangeLog for Work Order $jcn-$seq", '', $titleLink, false, 0);
+			}
+			else
+			{
+				print('<center>');
+				print("No ChangeLog for Work Order $jcn-$seq<p>");
+				print('</center>');
+
+				$obj = CreateObject('dcl.htmlWorkOrderDetail');
+				$obj->Show($jcn, $seq);
+			}
+		}
+	}
+
 	function my($rowlimit = 5)
 	{
 		$obj = CreateObject('dcl.dbWorkorders');
@@ -393,7 +456,7 @@ class htmlWorkorders
 				$objView->AddDef('filternot', 'responsible', $GLOBALS['DCLID']);
 			$objView->AddDef('order', '', array('priorities.weight', 'severities.weight', 'deadlineon', 'eststarton', 'jcn', 'seq'));
 
-			$objHV = CreateObject('dcl.htmlView');
+			$objHV = CreateViewObject($objView->table);
 			$objHV->Render($objView);
 			return;
 		}
@@ -411,20 +474,21 @@ class htmlWorkorders
 
 		$query .= ' ORDER BY b.weight,c.weight,a.deadlineon,a.eststarton,a.jcn,a.seq ';
 
-		if ($rowlimit > 0)
-			$obj->LimitQuery($query, 0, $rowlimit);
-		else
-			$obj->Query($query);
+		$obj->LimitQuery($query, 0, $rowlimit);
+
+		$t = CreateTemplate(array('hForm' => 'htmlMy.tpl'));
+		$t->set_block('hForm', 'row', 'hRow');
+		$t->set_block('hForm', 'nothing', 'hNothing');
+		$t->set_var('hRow', '');
+		$t->set_var('hNothing', '');
+
+		$t->set_var('TXT_TITLE', $title);
+		$t->set_var('TXT_TOP', sprintf(STR_CMMN_TOPNUM, $rowlimit));
 
-		BeginChocoTable(false);
-		
 		if ($forField == 'responsible')
-			print('<tr><th><a class="alightu" href="' . menuLink('', 'menuAction=htmlWorkorders.show&filterReportto=' . $GLOBALS['DCLID']) . '">');
+			$t->set_var('LNK_MY', menuLink('', 'menuAction=htmlWorkorders.show&filterReportto=' . $GLOBALS['DCLID']));
 		else
-			print("<tr><th><a class=\"alightu\" href=\"" . menuLink('', "menuAction=boWorkorders.showmy&which=$forField") . "\">");
-
-		print($title);
-		print('</a>');
+			$t->set_var('LNK_MY', menuLink('', "menuAction=boWorkorders.showmy&which=$forField"));
 
 		$objToday = new DCLDate;
 		$objToday->SetFromDisplay(date($dcl_info['DCL_DATE_FORMAT']));
@@ -432,10 +496,6 @@ class htmlWorkorders
 		$objStart = new DCLDate;
 		$objEstStart = new DCLDate;
 
-		PrintWithChocoFont('&nbsp;&nbsp;(' . sprintf(STR_CMMN_TOPNUM, $rowlimit) . ')');
-
-		print('</th></tr>');
-
 		if ($obj->next_record())
 		{
 			$i = 0;
@@ -448,11 +508,6 @@ class htmlWorkorders
 				else
 					$objStart->time = 0;
 
-				if ($i++ % 2 == 0)
-					print('<tr><td bgcolor="#FFFFFF">');
-				else
-					print('<tr><td bgcolor="' . $dcl_info['DCL_COLOR_LIGHT'] . '">');
-
 				// Print schedule status marker as appropriate
 				$statusColor = '';
 				if ($objToday->time > $objDeadline->time || ($objToday->time > $objEstStart->time && $objStart->time == 0))
@@ -462,78 +517,28 @@ class htmlWorkorders
 				elseif ($objToday->time >= ($objDeadline->time - 7 * 86400) || $objToday->time >= ($objEstStart->time - 7 * 86400))
 					$statusColor = '#00CE00';
 
+				$val_row = '';
 				if ($statusColor != '')
 				{
-					printf('<font style="color: %s;">', $statusColor);
-					print('<b>!</b>&nbsp;');
-					EndFont();
+					$val_row .= sprintf('<span style="color: %s; font-weight: bold;">!</span>&nbsp;', $statusColor);
 				}
 
-				$sMenuAction = menuLink('', 'menuAction=boWorkorders.viewjcn&jcn=' . $obj->f('jcn') . '&seq=' . $obj->f('seq'));
-				printf('<a class="adark" href="%s">(%d-%d) %s</a>',
-					$sMenuAction,
-					$obj->f('jcn'),
-					$obj->f('seq'),
-					htmlspecialchars($obj->f('summary')));
+				$val_row .= sprintf('(%d-%d) %s', $obj->f('jcn'), $obj->f('seq'), htmlspecialchars($obj->f('summary')));
 
-				print('</td></tr>');
+				$t->set_var('COLOR_ROW', ($i++ % 2 == 0 ? '#cecece' : $dcl_info['DCL_COLOR_LIGHT']));
+				$t->set_var('LNK_ROW', menuLink('', 'menuAction=boWorkorders.viewjcn&jcn=' . $obj->f('jcn') . '&seq=' . $obj->f('seq')));
+				$t->set_var('VAL_ROW', $val_row);
+				$t->parse('hRow', 'row', true);
 			}
 			while ($obj->next_record());
 		}
 		else
 		{
-			print('<tr><td bgcolor="#FFFFFF">');
-			print($noneMsg);
-			print('</td></tr>');
+			$t->set_var('TXT_NOTHING', $noneMsg);
+			$t->parse('hNothing', 'nothing');
 		}
 
-		print('</td></tr></table>');
-	}
-
-	function RenderOptions(&$aRecord)
-	{
-		$str = '<td>';
-		$str .= '<a class="adark" href="' . menuLink('', 'menuAction=boWorkorders.viewjcn&jcn=' . $aRecord['jcn'] . '&seq=' . $aRecord['seq']) . '">' . STR_CMMN_VIEW . '</a>';
-		//$str .= '&nbsp;|&nbsp;';
-		$str .= '</td>';
-		echo $str;
-	}
-
-	function RenderFilter(&$sPagerFormElements)
-	{
-		$filterStatus = IsSet($GLOBALS['filterStatus']) ? $GLOBALS['filterStatus'] : -1;
-		$filterReportto = IsSet($GLOBALS['filterReportto']) ? $GLOBALS['filterReportto'] : 0;
-		$filterProduct = IsSet($GLOBALS['filterProduct']) ? $GLOBALS['filterProduct'] : 0;
-
-		echo '<form method="post" action="' . menuLink('') . '">';
-		echo $sPagerFormElements;
-		echo '<br><b>', STR_WO_STATUS, ':</b>';
-
-		$o = CreateObject('dcl.htmlSelect');
-		$o->vDefault = $filterStatus;
-		$o->sName = 'filterStatus';
-		$o->iSize = 0;
-		$o->sZeroOption = STR_CMMN_SELECTONE;
-
-		$oStatus = CreateObject('dcl.dbStatuses');
-		$oStatus->Connect();
-		$oStatus->Query('SELECT id, name FROM statuses ORDER BY name');
-		$o->aOptions = $oStatus->FetchAllRows();
-		$i = count($o->aOptions);
-		$o->aOptions[$i++] = array('-1', STR_CMMN_HIDECLOSEDTYPES);
-		$o->aOptions[$i++] = array('-2', STR_CMMN_ONLYCLOSEDTYPES);
-		echo $o->GetHTML();
-
-		echo '&nbsp;<b>', STR_WO_RESPONSIBLE, ':</b>';
-		$oReport = CreateObject('dcl.htmlPersonnel');
-		$oReport->createCombo($filterReportto, 'filterReportto', 'short', 0, false);
-
-		echo '&nbsp;<b>', STR_WO_PRODUCT, ':</b>';
-		$oProduct = CreateObject('dcl.htmlProducts');
-		$oProduct->createCombo($filterProduct, 'filterProduct', 'name', 0, false);
-
-		echo '&nbsp;<input type="submit" value="Filter">';
-		echo '</form>';
+		$t->pparse('out', 'hForm');
 	}
 
 	function show()
@@ -541,22 +546,27 @@ class htmlWorkorders
 		global $dcl_info;
 
 		commonHeader();
-
+		
 		$oView = CreateObject('dcl.boView');
-		if (IsSet($GLOBALS['btnNav']) && IsSet($GLOBALS['startrow']) && IsSet($GLOBALS['numrows']))
+		if ((IsSet($GLOBALS['btnNav']) || IsSet($GLOBALS['jumptopage'])) && IsSet($GLOBALS['startrow']) && IsSet($GLOBALS['numrows']))
 		{
-			if ($GLOBALS['btnNav'] == '<<')
-			{
+			if (IsSet($GLOBALS['btnNav']) && $GLOBALS['btnNav'] == '<<')
 				$oView->startrow = $GLOBALS['startrow'] - $GLOBALS['numrows'];
-				if ($oView->startrow < 0)
-					$objView->startrow = 0;
-				$oView->numrows = $GLOBALS['numrows'];
-			}
+			else if (IsSet($GLOBALS['btnNav']) && $GLOBALS['btnNav'] == '>>')
+				$oView->startrow = $GLOBALS['startrow'] + $GLOBALS['numrows'];
 			else
 			{
-				$oView->startrow = $GLOBALS['startrow'] + $GLOBALS['numrows'];
-				$oView->numrows = $GLOBALS['numrows'];
+				$iPage = $GLOBALS['jumptopage'];
+				if ($iPage < 1)
+					$iPage = 1;
+
+				$oView->startrow = ($iPage - 1) * $GLOBALS['numrows'];
 			}
+
+			if ($oView->startrow < 0)
+				$oView->startrow = 0;
+
+			$oView->numrows = $GLOBALS['numrows'];
 		}
 		else
 		{
@@ -566,12 +576,13 @@ class htmlWorkorders
 
 		$oView->style = 'report';
 		$oView->title = STR_WO_BROWSEWO;
-		$oView->AddDef('columns', '', array('jcn', 'seq', 'products.name', 'statuses.name', 'priorities.name', 'severities.name', 'responsible.short', 'deadlineon', 'summary'));
+		$oView->AddDef('columns', '', array('jcn', 'seq', 'dcl_wo_type.type_name', 'products.name', 'statuses.name', 'priorities.name', 'severities.name', 'responsible.short', 'deadlineon', 'summary'));
 		$oView->AddDef('order', '', array('priorities.weight', 'severities.weight', 'deadlineon', 'eststarton', 'jcn', 'seq'));
 
 		$oView->AddDef('columnhdrs', '', array(
 				STR_WO_JCN,
 				STR_WO_SEQ,
+				STR_WO_TYPE,
 				STR_WO_PRODUCT,
 				STR_WO_STATUS,
 				STR_WO_PRIORITY,
@@ -583,12 +594,15 @@ class htmlWorkorders
 		$filterStatus = '-1';
 		$filterReportto = '0';
 		$filterProduct = '0';
+		$filterType = '0';
 		if (IsSet($GLOBALS['filterStatus']))
 			$filterStatus = $GLOBALS['filterStatus'];
 		if (IsSet($GLOBALS['filterReportto']))
 			$filterReportto = $GLOBALS['filterReportto'];
 		if (IsSet($GLOBALS['filterProduct']))
 			$filterProduct = $GLOBALS['filterProduct'];
+		if (IsSet($GLOBALS['filterType']))
+			$filterType = $GLOBALS['filterType'];
 
 		if ($filterStatus != '0')
 		{
@@ -606,10 +620,10 @@ class htmlWorkorders
 		if ($filterProduct != '0')
 			$oView->AddDef('filter', 'product', $filterProduct);
 
-		$oHtml = CreateObject('dcl.htmlView');
-		$oHtml->oCallback = $this;
-		$oHtml->sCallback = 'RenderOptions';
-		$oHtml->sFilterCallback = 'RenderFilter';
+		if ($filterType != '0')
+			$oView->AddDef('filter', 'wo_type_id', $filterType);
+
+		$oHtml = CreateObject('dcl.htmlWorkOrderBrowse');
 		$oHtml->sColumnTitle = STR_CMMN_OPTIONS;
 		$oHtml->sPagingMenuAction = 'htmlWorkorders.show';
 		$oHtml->bColumnSort = false;
