@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: main.php,v 1.4.2.1 2002/02/15 07:06:27 mdean Exp $
+ * $Id: main.php,v 1.4.2.1.2.8 2004/01/01 18:20:00 mdean Exp $
  *
  * Double Choco Latte - Source Configuration Management System
  * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
@@ -22,48 +22,18 @@
  * Select License Info from the Help menu to view the terms and conditions of this license.
  */
 
-$bInPHPGroupWare = false;
-$bNoHeader = false;
-if (file_exists('../header.inc.php'))
+include_once('login.php');
+
+$g_oSec = CreateObject('dcl.boSecurity');
+
+$g_oPage = GetPageObject();
+$g_oPage->StartPage();
+
+if (IsSet($menuAction) && $menuAction != 'clearScreen')
 {
-	$phpgw_info['flags'] = array(
-			'currentapp' => 'dcl',
-			'noheader'   => True,
-			'nonavbar'   => True
-		);
-	include('../header.inc.php');
-	$bInPHPGroupWare = (isset($phpgw) && is_object($phpgw));
-	$bNoHeader = (IsSet($menuAction) && ($menuAction == 'htmlTicketDetail.Download' || $menuAction == 'htmlWorkOrderDetail.Download' || $menuAction == 'boGraph.Show'));
-}
-if (!$bNoHeader)
-{
-	if ($bInPHPGroupWare)
-	{
-		$phpgw->common->phpgw_header();
-		echo parse_navbar();
-	}
-	else
-	{
-		include('login.php');
-	}
-}
-if (IsSet($menuAction))
-{
-	if ($menuAction == 'clearScreen')
-	{
-		commonHeader();
-		if ($bInPHPGroupWare)
-			$phpgw->common->phpgw_footer();
-		else
-			commonFooter();
-		exit;
-	}
-	$g_oSec = CreateObject('dcl.boSecurity');
 	if ($g_oSec->ValidateMenuAction() == true)
 	{
-		list($class, $method) = explode(".", $menuAction);
-		$obj = CreateObject('dcl.' . $class);
-		eval("\$obj->$method();");
+		Invoke($menuAction);
 	}
 	else
 	{
@@ -76,11 +46,5 @@ else
 	commonHeader();
 }
 
-if (!$bNoHeader)
-{
-	if ($bInPHPGroupWare)
-		$phpgw->common->phpgw_footer();
-	else
-		commonFooter();
-}
+$g_oPage->EndPage();
 ?>
