@@ -1,7 +1,7 @@
 # phpMyAdmin MySQL-Dump
 # http://www.htmlwizard.net/phpMyAdmin/
 #
-# $Id: createdb.sql,v 1.6.2.8.2.5 2003/01/29 05:12:33 mdean Exp $
+# $Id: createdb.sql,v 1.6.2.8.2.11 2003/05/09 02:56:19 mdean Exp $
 #
 # Host: localhost Database : dcl
 
@@ -26,7 +26,9 @@ CREATE TABLE accounts (
 		data2 varchar(10),
 		notes text,
 		active varchar(1) default 'Y',
-		PRIMARY KEY (id)
+		PRIMARY KEY (id),
+		UNIQUE uc_accounts_short (short),
+		UNIQUE uc_accounts_name (name)
 	);
 
 #
@@ -239,7 +241,6 @@ CREATE TABLE workorders (
 		jcn int(11) DEFAULT '0' NOT NULL,
 		seq int(11) DEFAULT '0' NOT NULL,
 		product int(11) DEFAULT '0' NOT NULL,
-		account int(11),
 		createby int(11) DEFAULT '0' NOT NULL,
 		createdon timestamp(14),
 		closedby int(11),
@@ -266,6 +267,7 @@ CREATE TABLE workorders (
 		oid int(11) DEFAULT '0' NOT NULL auto_increment,
 		etchours float(10,2),
 		module_id int(11),
+		wo_type_id int(11),
 		PRIMARY KEY (oid)
 	);
 
@@ -493,7 +495,7 @@ CREATE TABLE dcl_product_module (
 		PRIMARY KEY (product_module_id)
 	);
 
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_VERSION','dcl_config_varchar',NULL,NULL,NULL,NULL,'0.9.2');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_VERSION','dcl_config_varchar',NULL,NULL,NULL,NULL,'0.9.3');
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DATE_FORMAT','dcl_config_varchar',NULL,NULL,NULL,NULL,'m/d/Y');
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DATE_FORMAT_DB','dcl_config_varchar',NULL,NULL,NULL,NULL,'Y-m-d');
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_TIMESTAMP_FORMAT_DB','dcl_config_varchar',NULL,NULL,NULL,NULL,'YmdHis');
@@ -550,13 +552,64 @@ insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) v
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WO_EMAIL_TEMPLATE', 'dcl_config_varchar', 'notify_wo_en.tpl');
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_TCK_NOTIFICATION_HTML', 'dcl_config_varchar', 'N');
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_TCK_EMAIL_TEMPLATE', 'dcl_config_varchar', 'notify_tck_en.tpl');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_AUTORESPOND', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_AUTORESPONSE_EMAIL', 'dcl_config_varchar', 'nobody@localhost');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_ENABLED', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_FILE_PATH', 'dcl_config_varchar', '/tmp');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_WO_PRIORITY', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_REPLY', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_WO_SEVERITY', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_WO_STATUS', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WO_SECONDARY_ACCOUNTS_ENABLED', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_datetime) values ('LAST_CONFIG_UPDATE', 'dcl_config_datetime', now());
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_SESSION_TIMEOUT', 'dcl_config_int', 20);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WIKI_ENABLED', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_WIKI_VIEW', 'dcl_config_int', 4);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_WIKI_EDIT', 'dcl_config_int', 5);
+
+Create Table dcl_wo_account (
+	wo_id int(11) not null,
+	seq int(11) not null,
+	account_id int(11) not null,
+	primary key(wo_id, seq, account_id)
+);
+
+Create Table dcl_wo_type (
+	wo_type_id int(11) auto_increment not null primary key,
+	type_name varchar(50) not null,
+	active char(1) not null
+);
 
 create table dcl_status_type (
-		dcl_status_type_id int(11) not null,
-		dcl_status_type_name varchar(50) not null,
-		primary key(dcl_status_type_id)
-	);
+	dcl_status_type_id int(11) not null,
+	dcl_status_type_name varchar(50) not null,
+	primary key(dcl_status_type_id)
+);
+
+Create Table dcl_session (
+	dcl_session_id varchar(32) not null primary key,
+	personnel_id int(11) not null,
+	create_date timestamp(14) not null,
+	update_date timestamp(14) not null,
+	session_data text
+);
+
+Create Table dcl_preferences (
+	personnel_id int(11) not null primary key,
+	preferences_data text
+);
 
 insert into dcl_status_type values (1, 'Open');
 insert into dcl_status_type values (2, 'Completed');
 insert into dcl_status_type values (3, 'Deferred');
+
+Create Table dcl_wiki (
+	dcl_entity_type_id int(11) not null,
+	dcl_entity_id int(11) not null,
+	dcl_entity_id2 int(11) not null,
+	page_name varchar(255) not null,
+	page_text text null,
+	page_date timestamp(14) null,
+	page_ip varchar(255) null,
+	primary key (dcl_entity_type_id, dcl_entity_id, dcl_entity_id2, page_name)
+);
