@@ -8,7 +8,7 @@ create SEQUENCE seq_faqtopics;
 create SEQUENCE seq_faqquestions;
 create SEQUENCE seq_faqanswers;
 create SEQUENCE seq_timecards;
-create SEQUENCE seq_severity;
+create SEQUENCE seq_severities;
 create SEQUENCE seq_departments;
 create SEQUENCE seq_jcn;
 create SEQUENCE seq_projects;
@@ -21,10 +21,11 @@ create SEQUENCE seq_statuses;
 create SEQUENCE seq_dcl_chklst;
 create SEQUENCE seq_dcl_chklst_tpl;
 create SEQUENCE seq_dcl_product_module;
+Create SEQUENCE seq_dcl_wo_type;
 
 create TABLE personnel (
 		id number(11,0) not null primary key,
-		short char(10) not null unique, 
+		short char(10) not null unique,
 		lastname varchar2(25), 
 		firstname varchar2(20), 
 		reportto number(11,0), 
@@ -38,7 +39,7 @@ create TABLE personnel (
 create TABLE accounts (
 		id number(11,0) not null primary key, 
 		short char(10) not null unique, 
-		name varchar2(30) not null, 
+		name varchar2(30) not null unique, 
 		add1 varchar2(30), 
 		add2 varchar2(30), 
 		city varchar2(50), 
@@ -83,6 +84,7 @@ create TABLE statuses (
 		id number(11,0) not null primary key, 
 		short char(10) not null unique, 
 		name varchar2(20) not null,
+		dcl_status_type number(11, 0) default '1' not null,
 		active varchar2(1) default 'Y'
 	);
 
@@ -120,35 +122,35 @@ create TABLE workorders (
 		jcn number(11,0) not null, 
 		seq number(11,0) not null, 
 		product number(11,0) not null, 
-		account number(11,0), 
-		createby number(11,0) not null, 
-		createdon date not null, 
-		closedby number(11,0), 
-		closedon date, 
-		status number(11,0) not null, 
-		statuson date not null, 
-		lastactionon date, 
-		deadlineon date, 
-		eststarton date, 
-		estendon date, 
-		starton date, 
-		esthours number(12,4), 
-		totalhours number(12,4), 
-		priority number(11,0) not null, 
-		severity number(11,0) not null, 
-		contact varchar2(50), 
-		contactphone char(10), 
-		summary varchar2(100) not null, 
-		notes varchar2(1024), 
-		description varchar2(1024) not null, 
-		responsible number(11,0), 
-		revision varchar2(20), 
-		publicview number(1), 
-		notifycreateby number(1), 
-		notifyproductlead number(1), 
-		notifyresponsible number(1), 
+		createby number(11,0) not null,
+		createdon date not null,
+		closedby number(11,0),
+		closedon date,
+		status number(11,0) not null,
+		statuson date not null,
+		lastactionon date,
+		deadlineon date,
+		eststarton date,
+		estendon date,
+		starton date,
+		esthours number(12,4),
+		totalhours number(12,4),
+		priority number(11,0) not null,
+		severity number(11,0) not null,
+		contact varchar2(50),
+		contactphone char(10),
+		summary varchar2(100) not null,
+		notes varchar2(1024),
+		description varchar2(1024) not null,
+		responsible number(11,0),
+		revision varchar2(20),
+		publicview number(1),
+		notifycreateby number(1),
+		notifyproductlead number(1),
+		notifyresponsible number(1),
 		etchours number(12,4),
-		module_id number(11, 0)
+		module_id number(11, 0),
+		wo_type_id number(11,0)
 	);
 
 create table dcl_projects (
@@ -392,7 +394,7 @@ INSERT INTO attributesetsmap SELECT 2, 4, id, 1 FROM statuses;
 commit;
 
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) 
-	VALUES ('DCL_VERSION','dcl_config_varchar',NULL,NULL,NULL,NULL,'0.9.1');
+	VALUES ('DCL_VERSION','dcl_config_varchar',NULL,NULL,NULL,NULL,'0.9.3');
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) 
 	VALUES ('DCL_DATE_FORMAT','dcl_config_varchar',NULL,NULL,NULL,NULL,'m/d/Y');
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) 
@@ -461,6 +463,8 @@ INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_c
 	VALUES ('DCL_SMTP_PORT','dcl_config_int',25,NULL,NULL,NULL,NULL);
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) 
 	VALUES ('DCL_SMTP_TIMEOUT','dcl_config_int',30,NULL,NULL,NULL,NULL);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_datetime)
+	values ('LAST_CONFIG_UPDATE', 'dcl_config_datetime', sysdate);
 commit;
 
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) 
@@ -492,8 +496,46 @@ insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) v
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WO_EMAIL_TEMPLATE', 'dcl_config_varchar', 'notify_wo_en.tpl');
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_TCK_NOTIFICATION_HTML', 'dcl_config_varchar', 'N');
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_TCK_EMAIL_TEMPLATE', 'dcl_config_varchar', 'notify_tck_en.tpl');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_AUTORESPOND', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_AUTORESPONSE_EMAIL', 'dcl_config_varchar', 'nobody@localhost');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_ENABLED', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_FILE_PATH', 'dcl_config_varchar', '/tmp');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_WO_PRIORITY', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_REPLY', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_WO_SEVERITY', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_WO_STATUS', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WO_SECONDARY_ACCOUNTS_ENABLED', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_SESSION_TIMEOUT', 'dcl_config_int', 20);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WIKI_ENABLED', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_WIKI_VIEW', 'dcl_config_int', 4);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_WIKI_EDIT', 'dcl_config_int', 5);
 commit;
 
+Create Table dcl_wo_account (
+	wo_id number(11, 0) not null,
+	seq number(11, 0) not null,
+	account_id number(11, 0) not null,
+	primary key(wo_id, seq, account_id)
+);
+
+Create Table dcl_wo_type (
+	wo_type_id number(11, 0) not null primary key,
+	type_name varchar2(50) not null,
+	active char(1) not null
+);
+
+Create Table dcl_session (
+	dcl_session_id varchar2(32) not null primary key,
+	personnel_id number(11, 0) not null,
+	create_date date not null,
+	update_date date not null,
+	session_data clob
+);
+
+Create Table dcl_preferences (
+	personnel_id number(11, 0) not null primary key,
+	preferences_data clob
+);
 
 create table dcl_status_type (
 		dcl_status_type_id number(11,0) not null primary key,
@@ -504,3 +546,14 @@ insert into dcl_status_type values (1, 'Open');
 insert into dcl_status_type values (2, 'Completed');
 insert into dcl_status_type values (3, 'Deferred');
 commit;
+
+Create Table dcl_wiki (
+	dcl_entity_type_id number(11, 0) not null,
+	dcl_entity_id number(11, 0) not null,
+	dcl_entity_id2 number(11, 0) not null,
+	page_name varchar2(255) not null,
+	page_text clob null,
+	page_date date null,
+	page_ip varchar2(255) null,
+	primary key (dcl_entity_type_id, dcl_entity_id, dcl_entity_id2, page_name)
+);
