@@ -64,6 +64,10 @@ CREATE TABLE "accounts" (
 		"active" varchar(1) default 'Y'
 	);
 
+create unique index "uc_accounts_short" on accounts("short");
+create unique index "uc_accounts_name" on accounts("name");
+
+
 CREATE TABLE "actions" (
 		"id" "int4" NOT NULL, 
 		"short" char(10) NOT NULL, 
@@ -103,7 +107,7 @@ CREATE TABLE "timecards" (
 		"jcn" "int4" NOT NULL, 
 		"seq" "int4" NOT NULL, 
 		"actionon" "date" NOT NULL, 
-		"inputon" "timestamp" DEFAULT text 'now' NOT NULL, 
+		"inputon" "timestamp" DEFAULT now() NOT NULL, 
 		"actionby" "int4" NOT NULL, 
 		"status" "int4" NOT NULL, 
 		"action" "int4" NOT NULL, 
@@ -124,45 +128,43 @@ CREATE TABLE "severities" (
 	);
 
 CREATE TABLE "departments" (
-		"id" "int4" NOT NULL, 
+		"id" "int4" NOT NULL,
 		"short" char(10) NOT NULL, 
 		"name" varchar(30) NOT NULL,
 		"active" varchar(1) default 'Y'
 	);
 
 CREATE TABLE "workorders" (
-		"jcn" "int4" NOT NULL, 
-		"seq" "int4" NOT NULL, 
-		"product" "int4" NOT NULL, 
-		"account" "int4", 
-		"createby" "int4" NOT NULL, 
-		"createdon" "timestamp" NOT NULL, 
-		"closedby" "int4", 
-		"closedon" "date", 
-		"status" "int4" NOT NULL, 
-		"statuson" "timestamp" NOT NULL, 
-		"lastactionon" "timestamp", 
-		"deadlineon" "date", 
-		"eststarton" "date", 
-		"estendon" "date", 
-		"starton" "date", 
-		"esthours" "float8", 
-		"totalhours" "float8", 
-		"priority" "int4" NOT NULL, 
-		"severity" "int4" NOT NULL, 
-		"contact" varchar(50), 
-		"contactphone" char(10), 
-		"summary" varchar(100) NOT NULL, 
-		"notes" varchar(1024), 
-		"description" varchar(1024) NOT NULL, 
-		"responsible" "int4", 
-		"revision" varchar(20), 
-		"publicview" "bool", 
-		"notifycreateby" "bool", 
-		"notifyproductlead" "bool", 
-		"notifyresponsible" "bool", 
+		"jcn" "int4" NOT NULL,
+		"seq" "int4" NOT NULL,
+		"product" "int4" NOT NULL,
+		"createby" "int4" NOT NULL,
+		"createdon" "timestamp" NOT NULL,
+		"closedby" "int4",
+		"closedon" "date",
+		"status" "int4" NOT NULL,
+		"statuson" "timestamp" NOT NULL,
+		"lastactionon" "timestamp",
+		"deadlineon" "date",
+		"eststarton" "date",
+		"estendon" "date",
+		"starton" "date",
+		"esthours" "float8",
+		"totalhours" "float8",
+		"priority" "int4" NOT NULL,
+		"severity" "int4" NOT NULL,
+		"contact" varchar(50),
+		"contactphone" char(10),
+		"summary" varchar(100) NOT NULL,
+		"notes" varchar(1024),
+		"description" varchar(1024) NOT NULL,
+		"responsible" "int4",
+		"revision" varchar(20),
+		"publicview" "bool",
 		"etchours" "float8",
-		"module_id" "int4"
+		"module_id" "int4",
+		"wo_type_id" "int4",
+		primary key(jcn, seq)
 	);
 
 create table "dcl_projects" (
@@ -170,16 +172,16 @@ create table "dcl_projects" (
 		"name" varchar(100), 
 		"reportto" "int4" not null, 
 		"createdby" "int4" not null, 
-		"createdon" "datetime" not null default now(), 
+		"createdon" "timestamp" not null default now(), 
 		"projectdeadline" "date", 
 		"description" varchar(1024) not null, 
 		"status" "int4" not null, 
-		"lastactivity" "datetime", 
+		"lastactivity" "timestamp", 
 		"finalclose" "date",
 		"parentprojectid" int4 default('0') not null
 	);
 
-create unique index "projects_name_key" on projects("name");
+create unique index "projects_name_key" on dcl_projects("name");
 
 create table "projectmap" (
 		"projectid" "int4" not null, 
@@ -397,63 +399,77 @@ CREATE TABLE "dcl_config" (
 		PRIMARY KEY ("dcl_config_name")
 	);
 
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_VERSION','dcl_config_varchar',NULL,NULL,NULL,NULL,'0.9.2');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DATE_FORMAT','dcl_config_varchar',NULL,NULL,NULL,NULL,'m/d/Y');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DATE_FORMAT_DB','dcl_config_varchar',NULL,NULL,NULL,NULL,'Y-m-d');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_TIMESTAMP_FORMAT_DB','dcl_config_varchar',NULL,NULL,NULL,NULL,'Y-m-d H:i:s');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_TIMESTAMP_FORMAT','dcl_config_varchar',NULL,NULL,NULL,NULL,'m/d/Y H:i:s');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_MAX_UPLOAD_FILE_SIZE','dcl_config_int',1048576,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEFAULT_LANGUAGE','dcl_config_varchar',NULL,NULL,NULL,NULL,'en');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_PRIVATE_KEY','dcl_config_varchar',NULL,NULL,NULL,NULL,'IloveDCL');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_ROOT','dcl_config_varchar',NULL,NULL,NULL,NULL,'http://localhost/dcl/');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_ADD_USER','dcl_config_int',9,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEL_WO','dcl_config_int',8,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_MOD_WO','dcl_config_int',7,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_ASSIGN_WO','dcl_config_int',5,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_ADD_WO','dcl_config_int',3,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_HAVE_WO','dcl_config_int',4,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_CHG_PWD','dcl_config_int',2,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEF_STATUS_ASSIGN_WO','dcl_config_int',1,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEF_STATUS_UNASSIGN_WO','dcl_config_int',4,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEF_PRIORITY','dcl_config_int',1,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEF_SEVERITY','dcl_config_int',2,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_AUTO_DATE','dcl_config_varchar',NULL,NULL,NULL,NULL,'Y');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_TIME_CARD_ORDER','dcl_config_varchar',NULL,NULL,NULL,NULL,'ASC');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_PROJECT_XML_TEMPLATES','dcl_config_varchar',NULL,NULL,NULL,NULL,'N');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_GD_TYPE','dcl_config_varchar',NULL,NULL,NULL,NULL,'png');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_CQQ_PERCENT','dcl_config_int',0,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_CQQ_FROM','dcl_config_varchar',NULL,NULL,NULL,NULL,'Somebody <someone@somewhere.org>');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_CQQ_SUBJECT','dcl_config_varchar',NULL,NULL,NULL,NULL,'Thank You For Calling');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_CQQ_TEMPLATE','dcl_config_varchar',NULL,NULL,NULL,NULL,'cqqmail.tpl');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEF_TEMPLATE_SET','dcl_config_varchar',NULL,NULL,NULL,NULL,'default');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_COLOR_LIGHT','dcl_config_varchar',NULL,NULL,NULL,NULL,'#eeeef8');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_COLOR_DARK','dcl_config_varchar',NULL,NULL,NULL,NULL,'#737b9c');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_SMTP_SERVER','dcl_config_varchar',NULL,NULL,NULL,NULL,'localhost');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_SMTP_ENABLED','dcl_config_varchar',NULL,NULL,NULL,NULL,'Y');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_SMTP_PORT','dcl_config_int',25,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_SMTP_TIMEOUT','dcl_config_int',30,NULL,NULL,NULL,NULL);
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PROJECT_BROWSE_PARENTS_ONLY', 'dcl_config_varchar', 'N');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PROJECT_INCLUDE_PARENT_STATS', 'dcl_config_varchar', 'N');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PROJECT_INCLUDE_CHILD_STATS', 'dcl_config_varchar', 'Y');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_FILE_PATH', 'dcl_config_varchar', '.');
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_HTML_TITLE', 'dcl_config_varchar', 'Double Choco Latte - Copyright (C) 1998-2001 Michael L. Dean and Tim R. Norman');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_ADD_USER', 'dcl_config_int', 9);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_ADD_WO', 'dcl_config_int', 3);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_ASSIGN_WO', 'dcl_config_int', 5);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_AUTO_DATE', 'dcl_config_varchar', 'Y');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_CHG_PWD', 'dcl_config_int', 2);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_COLOR_DARK', 'dcl_config_varchar', '#000065');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_COLOR_LIGHT', 'dcl_config_varchar', '#eeeef8');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_CQQ_PERCENT', 'dcl_config_int', 0);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_CQQ_FROM', 'dcl_config_varchar', 'Somebody <someone@somewhere.org>');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_CQQ_SUBJECT', 'dcl_config_varchar', 'Thank You For Calling');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_CQQ_TEMPLATE', 'dcl_config_varchar', 'cqqmail.tpl');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_DATE_FORMAT', 'dcl_config_varchar', 'm/d/Y');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_DATE_FORMAT_DB', 'dcl_config_varchar', 'Y-m-d');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_DEFAULT_LANGUAGE', 'dcl_config_varchar', 'en');
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_DEFAULT_PROJECT_STATUS', 'dcl_config_int', 1);
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_DEFAULT_TICKET_STATUS', 'dcl_config_int', 1);
-insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_TICKET_ENABLED', 'dcl_config_varchar', 'N');
-insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_TICKET_AUTORESPOND', 'dcl_config_varchar', 'N');
-insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_TICKET_REPLY', 'dcl_config_varchar', 'N');
-insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_TICKET_AUTORESPONSE_EMAIL', 'dcl_config_varchar', 'nobody@localhost');
-insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_TICKET_FILE_PATH', 'dcl_config_varchar', '/tmp');
-insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_TICKET_STATUS', 'dcl_config_int', 0);
-insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_TICKET_PRIORITY', 'dcl_config_int', 0);
-insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_TICKET_SEVERITY', 'dcl_config_int', 0);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_DEF_PRIORITY', 'dcl_config_int', 1);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_DEF_SEVERITY', 'dcl_config_int', 2);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_DEF_STATUS_ASSIGN_WO', 'dcl_config_int', 1);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_DEF_STATUS_UNASSIGN_WO', 'dcl_config_int', 4);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_DEF_TEMPLATE_SET', 'dcl_config_varchar', 'default');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_DEL_WO', 'dcl_config_int', 8);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_FILE_PATH', 'dcl_config_varchar', '.');
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_TICKET_ACCOUNT', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_TICKET_AUTORESPOND', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_TICKET_AUTORESPONSE_EMAIL', 'dcl_config_varchar', 'nobody@localhost');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_TICKET_ENABLED', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_TICKET_FILE_PATH', 'dcl_config_varchar', '/tmp');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_TICKET_PRIORITY', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_TICKET_REPLY', 'dcl_config_varchar', 'N');
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_TICKET_REPLY_LOGGED_BY', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_TICKET_SEVERITY', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_TICKET_STATUS', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_AUTORESPOND', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_AUTORESPONSE_EMAIL', 'dcl_config_varchar', 'nobody@localhost');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_ENABLED', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_FILE_PATH', 'dcl_config_varchar', '/tmp');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_WO_PRIORITY', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_REPLY', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_WO_SEVERITY', 'dcl_config_int', 0);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_WO_STATUS', 'dcl_config_int', 0);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_GD_TYPE', 'dcl_config_varchar', 'png');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_HAVE_WO', 'dcl_config_int', 4);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_HTML_TITLE', 'dcl_config_varchar', 'Double Choco Latte - Copyright (C) 1998-2001 Michael L. Dean and Tim R. Norman');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_MAX_UPLOAD_FILE_SIZE', 'dcl_config_int', 1048576);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_MOD_WO', 'dcl_config_int', 7);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PRIVATE_KEY', 'dcl_config_varchar', 'IloveDCL');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PROJECT_BROWSE_PARENTS_ONLY', 'dcl_config_varchar', 'N');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PROJECT_INCLUDE_CHILD_STATS', 'dcl_config_varchar', 'Y');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PROJECT_INCLUDE_PARENT_STATS', 'dcl_config_varchar', 'N');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PROJECT_XML_TEMPLATES', 'dcl_config_varchar', 'N');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_ROOT', 'dcl_config_varchar', 'http://localhost/dcl/');
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_SMTP_DEFAULT_EMAIL', 'dcl_config_varchar', 'nobody@localhost');
-insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WO_NOTIFICATION_HTML', 'dcl_config_varchar', 'N');
-insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WO_EMAIL_TEMPLATE', 'dcl_config_varchar', 'notify_wo_en.tpl');
-insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_TCK_NOTIFICATION_HTML', 'dcl_config_varchar', 'N');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_SMTP_ENABLED', 'dcl_config_varchar', 'Y');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_SMTP_PORT', 'dcl_config_int', 25);
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_SMTP_SERVER', 'dcl_config_varchar', 'localhost');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_SMTP_TIMEOUT', 'dcl_config_int', 30);
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_TCK_EMAIL_TEMPLATE', 'dcl_config_varchar', 'notify_tck_en.tpl');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_TCK_NOTIFICATION_HTML', 'dcl_config_varchar', 'N');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_TIME_CARD_ORDER', 'dcl_config_varchar', 'ASC');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_TIMESTAMP_FORMAT', 'dcl_config_varchar', 'm/d/Y H:i:s');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_TIMESTAMP_FORMAT_DB', 'dcl_config_varchar', 'Y-m-d H:i:s');
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_VERSION', 'dcl_config_varchar', '0.9.3');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WO_EMAIL_TEMPLATE', 'dcl_config_varchar', 'notify_wo_en.tpl');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WO_NOTIFICATION_HTML', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WO_SECONDARY_ACCOUNTS_ENABLED', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_datetime) values ('LAST_CONFIG_UPDATE', 'dcl_config_datetime', now());
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_SESSION_TIMEOUT', 'dcl_config_int', 20);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WIKI_ENABLED', 'dcl_config_varchar', 'N');
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_WIKI_VIEW', 'dcl_config_int', 4);
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_WIKI_EDIT', 'dcl_config_int', 5);
 
 CREATE SEQUENCE "seq_dcl_chklst";
 CREATE TABLE "dcl_chklst" (
@@ -485,6 +501,38 @@ Create Table "dcl_product_module" (
 		PRIMARY KEY ("product_module_id")
 	);
 
+Create Table dcl_wo_account (
+	wo_id int4 not null,
+	seq int4 not null,
+	account_id int4 not null,
+	primary key(wo_id, seq, account_id)
+);
+
+
+Alter Table workorders Drop Column account;
+
+Create Sequence seq_dcl_wo_type;
+
+Create Table dcl_wo_type (
+	wo_type_id int4 not null default nextval('seq_dcl_wo_type'),
+	type_name varchar(50) not null,
+	active char(1) not null,
+	Primary Key(wo_type_id)
+);
+
+Create Table dcl_session (
+	dcl_session_id varchar(32) not null primary key,
+	personnel_id int4 not null,
+	create_date timestamp not null,
+	update_date timestamp not null,
+	session_data text null
+);
+
+Create Table dcl_preferences (
+	personnel_id int4 not null primary key,
+	preferences_data text null
+);
+
 create table dcl_status_type (
 		dcl_status_type_id int4 not null primary key,
 		dcl_status_type_name varchar(50) not null
@@ -493,3 +541,14 @@ create table dcl_status_type (
 insert into dcl_status_type values (1, 'Open');
 insert into dcl_status_type values (2, 'Completed');
 insert into dcl_status_type values (3, 'Deferred');
+
+Create Table dcl_wiki (
+	dcl_entity_type_id int4 not null,
+	dcl_entity_id int4 not null,
+	dcl_entity_id2 int4 not null,
+	page_name varchar(255) not null,
+	page_text text null,
+	page_date timestamp null,
+	page_ip varchar(255) null,
+	primary key (dcl_entity_type_id, dcl_entity_id, dcl_entity_id2, page_name)
+);
