@@ -1,4 +1,4 @@
--- $Id: createdb.sql,v 1.5.2.6.2.5 2003/01/29 05:12:34 mdean Exp $
+-- $Id: createdb.sql,v 1.5.2.6.2.13 2003/05/10 02:05:03 mdean Exp $
 --
 -- Host: localhost Database : dcl
 
@@ -30,6 +30,11 @@ CREATE TABLE accounts (
 	)
 go
 
+CREATE UNIQUE INDEX uc_accounts_short ON accounts(short)
+CREATE UNIQUE INDEX uc_accounts_name ON account(name)
+go
+
+
 --
 -- Dumping data for table 'accounts'
 --
@@ -288,7 +293,7 @@ CREATE TABLE workorders (
 		publicview tinyint NULL,
 		oid numeric(11,0) IDENTITY,
 		etchours float NULL,
-		module_id int,
+		module_id int NULL,
 		PRIMARY KEY (oid)
 	)
 go
@@ -360,25 +365,25 @@ go
 CREATE TABLE tickets (
 		ticketid numeric(11,0) IDENTITY NOT NULL,
 		product int NOT NULL,
-		account int,
+		account int NOT NULL,
 		createdby int NOT NULL,
 		createdon varchar(14)  NOT NULL,
 		responsible int NOT NULL,
-		closedby int,
-		closedon varchar(14),
+		closedby int NULL,
+		closedon varchar(14) NULL,
 		status int NOT NULL,
 		statuson varchar(14) NOT NULL,
-		lastactionon varchar(14),
+		lastactionon varchar(14) NULL,
 		priority int NOT NULL,
 		type int NOT NULL,
-		contact varchar(80),
-		contactphone varchar(20),
+		contact varchar(80) NULL,
+		contactphone varchar(20) NULL,
 		issue text NOT NULL,
-		version varchar(20),
-		summary varchar(100),
+		version varchar(20) NULL,
+		summary varchar(100) NULL,
 		seconds int DEFAULT '0' not null,
-		contactemail varchar(100),
-		module_id int,
+		contactemail varchar(100) NULL,
+		module_id int NULL,
 		PRIMARY KEY (ticketid)
 	)
 GO
@@ -398,12 +403,12 @@ GO
 CREATE TABLE faq (
 		faqid numeric(11,0) IDENTITY NOT NULL,
 		name varchar(80) NOT NULL,
-		createby int,
+		createby int NOT NULL,
 		createon varchar(14)  NOT NULL,
-		modifyby int,
-		modifyon varchar(14),
+		modifyby int NULL,
+		modifyon varchar(14) NULL,
 		active char(1) DEFAULT 'Y' NOT NULL,
-		description text,
+		description text NULL,
 		PRIMARY KEY (faqid)
 	)
 GO
@@ -414,10 +419,10 @@ CREATE TABLE faqtopics (
 		faqid int NOT NULL,
 		name varchar(80) NOT NULL,
 		description text NOT NULL,
-		createby int,
+		createby int NOT NULL,
 		createon varchar(14)  NOT NULL,
-		modifyby int,
-		modifyon varchar(14),
+		modifyby int NULL,
+		modifyon varchar(14) NULL,
 		active char(1) DEFAULT 'Y' NOT NULL,
 		PRIMARY KEY (topicid)
 	)
@@ -428,10 +433,10 @@ CREATE TABLE faqquestions (
 		seq int NOT NULL,
 		topicid int NOT NULL,
 		questiontext text NOT NULL,
-		createby int,
+		createby int NOT NULL,
 		createon varchar(14)  NOT NULL,
-		modifyby int,
-		modifyon varchar(14),
+		modifyby int NULL,
+		modifyon varchar(14) NULL,
 		active char(1) DEFAULT 'Y' NOT NULL,
 		PRIMARY KEY (questionid)
 	)
@@ -443,8 +448,8 @@ CREATE TABLE faqanswers (
 		answertext text NOT NULL,
 		createby int NOT NULL,
 		createon varchar(14)  NOT NULL,
-		modifyby int,
-		modifyon varchar(14),
+		modifyby int NULL,
+		modifyon varchar(14) NULL,
 		active char(1) DEFAULT 'Y' NOT NULL,
 		PRIMARY KEY (answerid)
 	)
@@ -518,9 +523,9 @@ CREATE TABLE dcl_chklst (
 	dcl_chklst_summary varchar(255) NOT NULL,
 	dcl_chklst_createby int NOT NULL,
 	dcl_chklst_createon varchar(14) NOT NULL,
-	dcl_chklst_modifyby int,
-	dcl_chklst_modifyon varchar(14),
-	dcl_chklst_status varchar(255),
+	dcl_chklst_modifyby int NULL,
+	dcl_chklst_modifyon varchar(14) NULL,
+	dcl_chklst_status varchar(255) NULL,
 	PRIMARY KEY (dcl_chklst_id)
 )
 GO
@@ -542,41 +547,41 @@ CREATE TABLE dcl_product_module (
 )
 GO
 
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_VERSION','dcl_config_varchar',NULL,NULL,NULL,NULL,'0.9.2')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DATE_FORMAT','dcl_config_varchar',NULL,NULL,NULL,NULL,'m/d/Y')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DATE_FORMAT_DB','dcl_config_varchar',NULL,NULL,NULL,NULL,'Ymd')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_TIMESTAMP_FORMAT_DB','dcl_config_varchar',NULL,NULL,NULL,NULL,'YmdHis')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_TIMESTAMP_FORMAT','dcl_config_varchar',NULL,NULL,NULL,NULL,'m/d/Y H:i:s')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_MAX_UPLOAD_FILE_SIZE','dcl_config_int',1048576,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEFAULT_LANGUAGE','dcl_config_varchar',NULL,NULL,NULL,NULL,'en')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_PRIVATE_KEY','dcl_config_varchar',NULL,NULL,NULL,NULL,'IloveDCL')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_ROOT','dcl_config_varchar',NULL,NULL,NULL,NULL,'http://localhost/dcl/')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_ADD_USER','dcl_config_int',9,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEL_WO','dcl_config_int',8,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_MOD_WO','dcl_config_int',7,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_ASSIGN_WO','dcl_config_int',5,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_ADD_WO','dcl_config_int',3,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_HAVE_WO','dcl_config_int',4,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_CHG_PWD','dcl_config_int',2,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEF_STATUS_ASSIGN_WO','dcl_config_int',1,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEF_STATUS_UNASSIGN_WO','dcl_config_int',4,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEF_PRIORITY','dcl_config_int',1,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEF_SEVERITY','dcl_config_int',2,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_AUTO_DATE','dcl_config_varchar',NULL,NULL,NULL,NULL,'Y')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_TIME_CARD_ORDER','dcl_config_varchar',NULL,NULL,NULL,NULL,'ASC')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_PROJECT_XML_TEMPLATES','dcl_config_varchar',NULL,NULL,NULL,NULL,'N')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_GD_TYPE','dcl_config_varchar',NULL,NULL,NULL,NULL,'png')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_CQQ_PERCENT','dcl_config_int',0,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_CQQ_FROM','dcl_config_varchar',NULL,NULL,NULL,NULL,'Somebody <someone@somewhere.org>')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_CQQ_SUBJECT','dcl_config_varchar',NULL,NULL,NULL,NULL,'Thank You For Calling')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_CQQ_TEMPLATE','dcl_config_varchar',NULL,NULL,NULL,NULL,'cqqmail.tpl')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_DEF_TEMPLATE_SET','dcl_config_varchar',NULL,NULL,NULL,NULL,'default')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_COLOR_LIGHT','dcl_config_varchar',NULL,NULL,NULL,NULL,'#eeeef8')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_COLOR_DARK','dcl_config_varchar',NULL,NULL,NULL,NULL,'#737b9c')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_SMTP_SERVER','dcl_config_varchar',NULL,NULL,NULL,NULL,'localhost')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_SMTP_ENABLED','dcl_config_varchar',NULL,NULL,NULL,NULL,'Y')
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_SMTP_PORT','dcl_config_int',25,NULL,NULL,NULL,NULL)
-INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int, dcl_config_double, dcl_config_date, dcl_config_datetime, dcl_config_varchar) VALUES ('DCL_SMTP_TIMEOUT','dcl_config_int',30,NULL,NULL,NULL,NULL)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_VERSION', 'dcl_config_varchar', '0.9.3')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_DATE_FORMAT', 'dcl_config_varchar', 'm/d/Y')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_DATE_FORMAT_DB', 'dcl_config_varchar', 'Ymd')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_TIMESTAMP_FORMAT_DB', 'dcl_config_varchar', 'YmdHis')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_TIMESTAMP_FORMAT', 'dcl_config_varchar', 'm/d/Y H:i:s')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_MAX_UPLOAD_FILE_SIZE', 'dcl_config_int', 1048576)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_DEFAULT_LANGUAGE','dcl_config_varchar', 'en')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PRIVATE_KEY','dcl_config_varchar', 'IloveDCL')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_ROOT', 'dcl_config_varchar', 'http://localhost/dcl/')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_ADD_USER', 'dcl_config_int', 9)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_DEL_WO', 'dcl_config_int', 8)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_MOD_WO', 'dcl_config_int', 7)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_ASSIGN_WO', 'dcl_config_int', 5)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_ADD_WO', 'dcl_config_int', 3)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_HAVE_WO', 'dcl_config_int', 4)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_CHG_PWD', 'dcl_config_int', 2)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_DEF_STATUS_ASSIGN_WO', 'dcl_config_int', 1)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_DEF_STATUS_UNASSIGN_WO', 'dcl_config_int', 4)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_DEF_PRIORITY', 'dcl_config_int', 1)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_DEF_SEVERITY', 'dcl_config_int', 2)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_AUTO_DATE', 'dcl_config_varchar', 'Y')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_TIME_CARD_ORDER', 'dcl_config_varchar', 'ASC')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PROJECT_XML_TEMPLATES', 'dcl_config_varchar', 'N')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_GD_TYPE', 'dcl_config_varchar', 'png')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_CQQ_PERCENT', 'dcl_config_int',0)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_CQQ_FROM', 'dcl_config_varchar', 'Somebody <someone@somewhere.org>')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_CQQ_SUBJECT', 'dcl_config_varchar', 'Thank You For Calling')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_CQQ_TEMPLATE', 'dcl_config_varchar', 'cqqmail.tpl')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_DEF_TEMPLATE_SET', 'dcl_config_varchar', 'default')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_COLOR_LIGHT', 'dcl_config_varchar', '#eeeef8')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_COLOR_DARK', 'dcl_config_varchar', '#737b9c')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_SMTP_SERVER', 'dcl_config_varchar', 'localhost')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_SMTP_ENABLED', 'dcl_config_varchar', 'Y')
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_SMTP_PORT', 'dcl_config_int', 25)
+INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) VALUES ('DCL_SMTP_TIMEOUT', 'dcl_config_int', 30)
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PROJECT_BROWSE_PARENTS_ONLY', 'dcl_config_varchar', 'N')
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PROJECT_INCLUDE_PARENT_STATS', 'dcl_config_varchar', 'N')
 INSERT INTO dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) VALUES ('DCL_PROJECT_INCLUDE_CHILD_STATS', 'dcl_config_varchar', 'Y')
@@ -599,6 +604,50 @@ insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) v
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WO_EMAIL_TEMPLATE', 'dcl_config_varchar', 'notify_wo_en.tpl')
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_TCK_NOTIFICATION_HTML', 'dcl_config_varchar', 'N')
 insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_TCK_EMAIL_TEMPLATE', 'dcl_config_varchar', 'notify_tck_en.tpl')
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_AUTORESPOND', 'dcl_config_varchar', 'N')
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_AUTORESPONSE_EMAIL', 'dcl_config_varchar', 'nobody@localhost')
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_ENABLED', 'dcl_config_varchar', 'N')
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_FILE_PATH', 'dcl_config_varchar', '/tmp')
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_WO_PRIORITY', 'dcl_config_int', 0)
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_GATEWAY_WO_REPLY', 'dcl_config_varchar', 'N')
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_WO_SEVERITY', 'dcl_config_int', 0)
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_GATEWAY_WO_STATUS', 'dcl_config_int', 0)
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WO_SECONDARY_ACCOUNTS_ENABLED', 'dcl_config_varchar', 'N')
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_datetime) values ('LAST_CONFIG_UPDATE', 'dcl_config_datetime', GetDate())
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_SESSION_TIMEOUT', 'dcl_config_int', 20)
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_varchar) values ('DCL_WIKI_ENABLED', 'dcl_config_varchar', 'N')
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_WIKI_VIEW', 'dcl_config_int', 4)
+insert into dcl_config (dcl_config_name, dcl_config_field, dcl_config_int) values ('DCL_WIKI_EDIT', 'dcl_config_int', 5)
+GO
+
+Create Table dcl_wo_account (
+	wo_id int not null,
+	seq int not null,
+	account_id int not null,
+	primary key(wo_id, seq, account_id)
+)
+GO
+
+Create Table dcl_wo_type (
+	wo_type_id numeric(11,0) IDENTITY not null primary key,
+	type_name varchar(50) not null,
+	active char(1) not null
+)
+GO
+
+Create Table dcl_session (
+	dcl_session_id varchar(32) not null primary key,
+	personnel_id int not null,
+	create_date datetime not null,
+	update_date datetime not null,
+	session_data text null
+)
+GO
+
+Create Table dcl_preferences (
+	personnel_id int not null primary key,
+	preferences_data text null
+)
 GO
 
 create table dcl_status_type (
@@ -611,3 +660,15 @@ insert into dcl_status_type values (1, 'Open')
 insert into dcl_status_type values (2, 'Completed')
 insert into dcl_status_type values (3, 'Deferred')
 GO
+
+Create Table dcl_wiki (
+	dcl_entity_type_id int not null,
+	dcl_entity_id int not null,
+	dcl_entity_id2 int not null,
+	page_name varchar(255) not null,
+	page_text text null,
+	page_date datetime null,
+	page_ip varchar(255) null,
+	primary key (dcl_entity_type_id, dcl_entity_id, dcl_entity_id2, page_name)
+)
+GO
